/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_CHAFFVERB_HPP_
#define _HEAVY_CONTEXT_CHAFFVERB_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalDel1.h"
#include "HvControlVar.h"
#include "HvControlBinop.h"
#include "HvMath.h"
#include "HvControlCast.h"
#include "HvTable.h"
#include "HvSignalTabwrite.h"
#include "HvControlUnop.h"
#include "HvControlTabhead.h"
#include "HvControlPack.h"
#include "HvControlSystem.h"
#include "HvControlDelay.h"
#include "HvSignalVar.h"
#include "HvSignalRPole.h"
#include "HvSignalPhasor.h"
#include "HvControlIf.h"
#include "HvControlSlice.h"
#include "HvSignalLine.h"
#include "HvControlRandom.h"
#include "HvSignalTabread.h"

class Heavy_ChaffVerb : public HeavyContext {

 public:
  Heavy_ChaffVerb(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_ChaffVerb();

  const char *getName() override { return "ChaffVerb"; }
  int getNumInputChannels() override { return 1; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        A__LFO_PERIOD = 0x1F30993F, // A__LFO_Period
        A__LFO_STEPS_SCALE__TYPE2 = 0x1A2B8E9F, // A__LFO_Steps_Scale__Type2
        A__LFO_STEPS__TYPE2 = 0xBE3344C8, // A__LFO_Steps__Type2
        A__LFO_SWITCH = 0x7369936E, // A__LFO_Switch
        A__LFO_TYPE = 0xD64CFD23, // A__LFO_type
        B__GENERAL_OFFSET = 0x51447E19, // B__General_Offset
        B__GENERAL_SCALE = 0xA10FCFC4, // B__General_Scale
        C__RANDOM_LFO_OFFSET = 0x7EFB8E46, // C__Random_LFO_Offset
        C__RANDOM_LFO_PERIOD = 0xE6223016, // C__Random_LFO_Period
        C__RANDOM_LFO_SCALE = 0x3281900D, // C__Random_LFO_Scale
        C__RANDOM_LFO_SWITCH = 0x6150BC53, // C__Random_LFO_Switch
        D__SHIFT_MICROTONE = 0x9CBB1BF3, // D__Shift_Microtone
        D__SHIFT_TRANSPOSE = 0x4439D71, // D__Shift_Transpose
        E__FX_LEVEL = 0x890283C2, // E__Fx_Level
        E__HIPASS_FREQ = 0x12962685, // E__HiPass_Freq
        E__SHIFT_DELAY = 0x183CFEE5, // E__Shift_Delay
        E__SHIFT_WINDOW = 0x57FF40DB, // E__Shift_Window
        F__FX_DELAY = 0x69A91334, // F__FX_Delay
        F__FX_DELAY_FEEDBACK = 0x68D029F7, // F__FX_Delay_Feedback
        MIX__DRY_MIX = 0xD63693D0, // Mix__Dry_Mix
        MIX__DRY_VOL = 0x1FC3C02C, // Mix__Dry_Vol
        MIX__REVERB_LEVEL = 0x58653D84, // Mix__Reverb_Level
        MIX__REVERB_VOL = 0xE764F673, // Mix__Reverb_Vol
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_OPQeRErB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FAV62Nt6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_sukqSXO8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_KGcHUblS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3jlHPp8k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fBy4WdvJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_LqWGzCsE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oPSXzheC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZBMUVoDH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c04O9FAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_BHv5HJGU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_UNNOp1B7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_BQyZVYx0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_iceV1m1l_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_WJQ006H4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_WO4aRDpi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nDI5NM33_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FRTzLqfP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jfU8iXJz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_foXuA8oP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JpwPkkZz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MZ0L4o4I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Xqn0GULS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_z3BsGTPI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JuBjlJal_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_QjxsqlMl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5dLhfxh4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A3wTl2VW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_11VltUxw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7w1Yx4dk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_v4AaPl24_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_b3JViUzi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_1vsnJLD3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GFavBSq9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bqlSdahY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AUUa2wof_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qSLPkcOX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EAuMAasL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8mtA9MyH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kSCZv2NK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pABrkwVo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_chKxkxdZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zErhscQE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gWCIf3SK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zc6ynir8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_zhXivI55_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_4Oj7Hbe5_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_ni7AxIO1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ARV5ZP2E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xEKb1F84_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3wr1fDK2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eR07JfjL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uvHpYS5q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GXQSexDf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dNjRU3xi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0HicDVWX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1KvHx0zP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PjSVFuwC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HfJHhk9u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CoDZvMac_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jRXx53AA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cC90eXYr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DS6vahZU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pGb4paBo_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_tceu9uQz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_6s0ELgrF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cRandom_uZGlEot1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_r9iMewng_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_sxE1rM2m_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_8r6cMHUH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lngTOVZj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2N9bKptX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_cRHHUhtZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lgWaErcI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Flyb9Ncd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ti39A92l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mftULQbM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JHNAIITP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_kbp9ZY19_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9BEkpWKN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_SMlWEC5w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_M4Mu8DTZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_stpocBAN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_rmGIPMZo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_voxtaPEX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rxQJoDlQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bwVSIcAD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MeXgiuul_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_clnAoCPM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6xvBmoHT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9bOC12DW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8F8fddys_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TeFKl0Gr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JKN7z1h0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3WVb3j2c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IFNxLmbS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ie5gG5xC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_449Ew2Ts_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hgNI4mgB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_egMGhvAM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3BuTpOJv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_qPaX44RG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_WBCGgNnK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_ctLULMbY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TGePZbnt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0p1CUark_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_31J7JUqT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_3PbBtz7x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FMHIb7tE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UydlxfED_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2aUzXwwI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WBLiUy5d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kwAYs1ZJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_orGBXCYe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MPDzeUCk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JjUF09gt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_PiwKv6yL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bdJ36u3R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_UKILptXO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_z56r03Rq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_b7Bh6mYR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_35UhAPtL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_Bwo6FKNV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E3xqO6mL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Lc5xn87v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zdIRmVsu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_vVCur4ZL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rDXmEUUl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qGqHczke_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xErKRWcc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ULMJGXE7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RtX3hbrJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1wWMEZpc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bCxm5Inx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WsHUdLiY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_8ABEGJvL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LZmz9gd9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_88uUyjpx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nFVe3oHL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ddw3la3Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_kfXQmJwV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_we43Zb4Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BwgFai7f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bk1JzQZQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f83e0GhO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_OrMClQrr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I1IqZwl0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qQ7hLotV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Bl8AX1jO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6sNtGTU2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lLeLe6hH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XCOMqxAn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ATfWsBAh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I6Ua28yM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JAcQcf3Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_XNHRHWER_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_LS97W8By_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xBxbU6sz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_gXHTUOXL_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_XczsfHf1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_w1CcRl7x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WyQoHKYp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zIwlgfdK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WWvs84eZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FS3pyTE8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MHJs6FGB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xLur4c50_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l68FpaAh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_kX6fSsaZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_bUPOxNzN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3SEzDdL1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_gmYEMO0N_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_8AGgZJej_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_HKOIdPB2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zbWhWEGW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qEbRRNpJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZifzqUEY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OlXATw7h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ypnc8pum_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eKjNeijP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YryOYtpC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Z6wU8uvj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3DKaYwww_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_kH02h8nS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_oO8dt0Uj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_9b1VVm4Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_weaGl6kg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dym2eUzC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A9o9Sv8J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tHK1VrCK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pYLfwcjp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uCzqiSiz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1xUCtGbu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_voTGrck6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JlqppTiU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_iurxkYN2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_qZAwpew2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5pvr8pMS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_VX07xZUT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_KwXYxzhr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9B9MMmy0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2mVSK3SS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MLGjHUsv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tUMV1BZ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8s21GGbi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kZpTeJNA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_aAwZ2G0R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_1lRklqTL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CGDehXv9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VeU9oGJy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Z3WHAwJW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nfOpOV86_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_QKIrvqxE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qQRdFZi6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5nqLqB7q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tNQp1NU3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x8bXgXQR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6qBe06N5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eNv4FVlL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OkpriRfd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_31QHT4BV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XsoDXfYE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_C8qvgVEY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_03zvhVOW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1pbcJvix_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l8G1Yp6S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AX1IYJBw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5ilJ1Xjx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_cf85wKly_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_vWTwwCWW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xigpHyBw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_sHokb4FL_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_oYIN6zcP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_Mgmx2cg1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c50bT9WM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hdt6gRPI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KFfWhJKA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rSXUktVb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ipxA60xu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qxRbzbW6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_YuSMcQsu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IBf6TNbc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_CjSwxC9c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_B1Hsykvz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_9F8I61nS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_XuwV73cU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_yTfcWTOF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4aSSszXe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aOHsof7v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e21mF30h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_tmTj6hr5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TX6DfCK1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8rQXZFTg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NPlKGRQN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9iXO750v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vR4lkQas_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VCzwGXEp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lVsWuqm8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fotr4QNm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LM0t4SnY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ZCkhd4lK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_o3YeXRwc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3CW05JD6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kGKuiUyq_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_1pWjJM4K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_ZeJYG2Hi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NxAdH1ab_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U00u69E3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a61OGBAd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ExVo8BzL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mTBZhiZs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U2Myb4ch_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_op7odMY5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_81oqzR5O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_GqMUpxje_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ILBjhUwg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_lhURGSVJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_j87KPjuE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_gc69BEPk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g8bguxDn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_poZnIrzN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_72tigk5C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2QHCzxC5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IOd40Ds0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Xkn9T92z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GhODPYu5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f6kTTIr4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0NjqL9KC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TBwuFjj9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZdgpdeqX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_91CDBl1H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b1F0mr6o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_94s6GKJp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_VMLbtWRb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_IYdRUWU6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_yiG0rb2t_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_ztxmuUze_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_lYyPC86n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L0RyNUHz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2xl5tLlM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dXoRYwE2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jRfEQ4D4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UfZPeJkb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BMh7DZpv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_yXkPKi2m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VaCjELye_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_jVfg1tG9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_A7pJbzQa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xEZCqDTI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_CoMl2W8a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_jd8v8eTI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eFiSLxHm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T5iYSDbs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oUVYyPCD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8DkIZidU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XglpDhQt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EHPorNju_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gB2gco1e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ARR0OOu3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SCU9UGbd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hk4onTfs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_djnk99Lw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_i87NJzh8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SMLWZ9R2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2iXrSHEG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_D6m5cNat_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_BLmR09sr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_yKs1oD8X_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_U36FebgB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_3tlLcWtp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sz1ANlmH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iyCFQCi7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dniOm1QV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HCseirPf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N5ta76aO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rjQFT8Xv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_hXO3fcjJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6Niutkem_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_sAA0mA2g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AaIFL8LU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_q40AgYgm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_79HrYtyk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_afV6PBIq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8AKgWEzW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nak7MDfD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IXZH2jZ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0eUuWaAN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tkxCOREo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QvMuZID3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bOiEcMS7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i8FMYRvg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tIytsxMw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fmYxIzOs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SgAts0sa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Pxj3Z1bC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yvhj2Hc2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_3MUdxLPs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_94epppIb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_5QTRdoNJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_gg0LJu56_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_dPaTGo6A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_dj8UlpVj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N6cJrrJf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Nj4xJwSZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QKEu9BQX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WDicLq01_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UtqqXlQo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pAKvaZ7D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_K7RyFZAL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ER4DJTYK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_NbeMwgYB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GneM7Q8c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Ho8NhQA0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_TWeYqmWR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_l34qTGku_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HgiWsFA4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qvRGAajQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aPmenPrI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7111Oyie_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pjAAxYa2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QFcUWkcP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ISUHIkm3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3uxHStoW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9RUQctuF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cVgfJjiD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w78IkyqI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_J3mhazDi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c1cjDpJV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_nXnnm8PR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_b3aiNhHx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_BZ1wUFvM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ZKKDzFzf_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_UyDhV6Ic_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_Hbzr2HCW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bep7PgpT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XsIvhF82_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O5Es6BC8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dt6lAlYS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_haT1S1ja_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o476UZEt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_1W4hWoEC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qvGX6TW2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_AjEpkMdX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LLwKJ2DY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_nOOb54TS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_OB5HtwN1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_D5pz8pIq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qCtb4Zrt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3dOebfph_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RFsc2eLb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_NT8QgS2m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qckRpXKt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6WqIc9yS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G37moVJT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hz0tCc6n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_plo76qyz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HFpTnaro_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Boq9Tgqi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0sr8bLzk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7eIZrsrH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_e4QjC6qu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_92Qv8Xf2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0vY0zf7a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9bYeIqsc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hOdRnXi4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6X9HX5j9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ymRtxmk5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cjEU0jaF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LGjKBMbH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qyi0torp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dxZ8zMSM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lMcABg8R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GfY6y3OS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_65MvfgOL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2uQu6Hod_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Pth6FFBK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w0lE9DOW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_au7CcuuU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pndV2h7o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZHIvFy7I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Xn3p4Wkh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vGRfmo66_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ZIgswIwu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L60BcJrr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3cTGmh13_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2DFOFtlD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pkBXYrLR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f6PYrP4o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xzfwI5cO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zRaqiAKp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CJS22Otw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5L4J4gc2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TsMSpxl0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GK6v2SzP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_HNplLjy3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kul8jChT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ubLYbhVr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_f7UMRRfD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_f7BAu6ZJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LsmgY8cV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_adYdiZ7w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q9i6AyN6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JKdNGvrL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SAYtVUv1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pF57YmUH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_4wODEjVD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_66UMbNdt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qT3VR0vL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SfyQIaZB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LG0SZseJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_6x9G4iF8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_VkkHeLhM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_EevCCH2a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_V3J65PL4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_uvLFGQ3o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_mIAgTbtp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zLkwZeUK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oR9Gieiy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1CdEppHK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Xl2jtKNs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nRck9ON5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VAgOopnF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_AW2BhyNt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vcD6nTP6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_1sFMeHbM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Gc8KXJNQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Cfx6xCKw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_2E1gdxeO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_Z2Rs1L7l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VXcbu3Ru_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h5KUEZwU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jkXtgQKc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_RGHTkuBB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N8H19BUo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yw4S8gH5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QtDIs4du_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gdYpZGuD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vqgDQLuU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4bURRFJP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kKwhalB9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_64Cj6UsP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_bVQ1z4YJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_ALjM3CGh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rUdcJEEk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_p12P9eSg_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_bSGpL9N5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Aczh8Mxg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PUENAyhw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MvNbwmLS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NB9wU9AZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_y55JL9rC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_8b9NAgzv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_BZxY6Qbt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Zbj0HRP7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0YOE2q0s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UMf3Fzz0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jeE33xAO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_j4PvWtNo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_LqqQlWl9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ihjzmfs7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_92mM6yLc_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_KZOiJutY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_5ULcDOyj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_I3HTsRbZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0v7mHeNz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wylY4QoV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Xn0F7hkN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N2xN9SWn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_b3jJh35X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SEL2717p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_pgEnseIu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_uHXb7ajr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tnSToyym_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_MCiLUuLp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_kZycz411_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_q3rDK5Ai_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lq3iT8P4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BUX5Ftml_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QcTynaPA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FWtEicuA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7ToFA9Mp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ir1OwoHK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5m8wKrhQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OkqMvj7h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tpPFnysf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4qzR92CY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_odsxXNxf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MdANpgLh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KI0pKpaJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aQmJHtAL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CAPkOIRD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_52oE43aW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wnWsOMms_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dJQGhVrX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TCLuiTMf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EZNsXLOq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2Cg2NSuh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XKT11r1t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NKNY9KJ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yuePTcK4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xFkNRah9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Oy9gjPeE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kRf6c3VH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_saqSZLmF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_59dxVqd1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0ypnCVZR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9SR9QxRz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_x4U7K5Sx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a43txA9g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2pTqvvMZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3sSgtaMP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cXYb0wpV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K92XLsKM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nDxYRgeS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q7WcSV8S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VcSU2W1F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AAah0Uzs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_if78PcrY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HqIQIZ2H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Zc3KaB9O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0aXaCiad_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_E2RHRskd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_POY7rgSw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Wn4pB0Ij_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pT7y5Ca9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Qc3Z9Elh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_p7Uc0oSo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LZy5LsT4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GRvxiMYi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Fznjw77K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fGelSoQ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Qii7GLtr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_P1ZphNSi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ddR4PL4V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9Q9WIloS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OiEPzm9Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qpVwdLES_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RslN4wDl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_o6othANf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_59frYoOB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5vIIEspB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rl9L58y3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DCDg1hWC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BIqY4UwO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_78PT4LC8_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalPhasor sPhasor_Ax5YbSyP;
  SignalLine sLine_0Y24QhQj;
  SignalLine sLine_7ps0Bip1;
  SignalTabhead sTabhead_TJQykQGL;
  SignalTabread sTabread_nFb8TAAo;
  SignalTabread sTabread_6CYHAJbK;
  SignalTabhead sTabhead_zzHC3LEB;
  SignalTabread sTabread_kmq1R0Op;
  SignalTabread sTabread_3wYqntri;
  SignalTabwrite sTabwrite_KMUQLhrV;
  SignalRPole sRPole_zSznCkul;
  SignalDel1 sDel1_t6GtLLlE;
  SignalTabread sTabread_Z2Rs1L7l;
  SignalTabwrite sTabwrite_LJaFtyr9;
  SignalTabread sTabread_voxtaPEX;
  SignalRPole sRPole_FiKuGxU7;
  SignalLine sLine_GQDNNPqU;
  SignalLine sLine_KzGWmAVR;
  SignalTabread sTabread_yTfcWTOF;
  SignalTabread sTabread_gc69BEPk;
  SignalTabread sTabread_jd8v8eTI;
  SignalTabread sTabread_afV6PBIq;
  SignalTabread sTabread_D5pz8pIq;
  SignalTabread sTabread_l34qTGku;
  SignalTabwrite sTabwrite_xvcTTCIt;
  SignalTabwrite sTabwrite_8WxOzIRJ;
  SignalTabwrite sTabwrite_f1b2SbLs;
  SignalTabwrite sTabwrite_KVZuN0wL;
  SignalTabwrite sTabwrite_eK1EKK8w;
  SignalTabwrite sTabwrite_jvWti33b;
  SignalTabread sTabread_ctLULMbY;
  SignalRPole sRPole_gq8w1ZlP;
  SignalTabread sTabread_Bwo6FKNV;
  SignalRPole sRPole_mVmkmH1I;
  SignalTabread sTabread_we43Zb4Y;
  SignalRPole sRPole_XML0uIro;
  SignalTabwrite sTabwrite_eF3lDk9I;
  SignalTabwrite sTabwrite_H2DgVUXc;
  SignalTabwrite sTabwrite_c0Yu9ky1;
  SignalTabwrite sTabwrite_GzhOi7Ay;
  SignalLine sLine_sKtHIecZ;
  ControlVar cVar_OPQeRErB;
  ControlVar cVar_FAV62Nt6;
  ControlPack cPack_sukqSXO8;
  ControlBinop cBinop_3jlHPp8k;
  ControlVar cVar_fBy4WdvJ;
  ControlPack cPack_LqWGzCsE;
  ControlVar cVar_oPSXzheC;
  ControlVar cVar_ZBMUVoDH;
  ControlDelay cDelay_UNNOp1B7;
  ControlDelay cDelay_BQyZVYx0;
  ControlBinop cBinop_WJQ006H4;
  HvTable hTable_WO4aRDpi;
  ControlBinop cBinop_FRTzLqfP;
  ControlVar cVar_JuBjlJal;
  ControlBinop cBinop_5dLhfxh4;
  ControlBinop cBinop_11VltUxw;
  SignalVarf sVarf_8y7lEkG8;
  SignalVarf sVarf_Ikhkn92g;
  SignalVarf sVarf_O01VgdzB;
  ControlVar cVar_b3JViUzi;
  ControlBinop cBinop_GFavBSq9;
  ControlBinop cBinop_AUUa2wof;
  SignalVarf sVarf_47rxuoI7;
  SignalVarf sVarf_riZcPc92;
  SignalVarf sVarf_LiUUr7W1;
  ControlBinop cBinop_qSLPkcOX;
  ControlBinop cBinop_EAuMAasL;
  ControlBinop cBinop_pABrkwVo;
  ControlBinop cBinop_chKxkxdZ;
  ControlBinop cBinop_zErhscQE;
  ControlBinop cBinop_gWCIf3SK;
  ControlBinop cBinop_zc6ynir8;
  ControlBinop cBinop_3wr1fDK2;
  ControlBinop cBinop_eR07JfjL;
  SignalVarf sVarf_8W9GCEti;
  ControlVar cVar_uvHpYS5q;
  ControlBinop cBinop_0HicDVWX;
  ControlBinop cBinop_1KvHx0zP;
  ControlBinop cBinop_HfJHhk9u;
  ControlBinop cBinop_CoDZvMac;
  ControlBinop cBinop_jRXx53AA;
  ControlBinop cBinop_cC90eXYr;
  ControlBinop cBinop_DS6vahZU;
  SignalVarf sVarf_4Jr7TZZR;
  ControlBinop cBinop_tceu9uQz;
  ControlRandom cRandom_uZGlEot1;
  ControlSlice cSlice_r9iMewng;
  ControlDelay cDelay_8r6cMHUH;
  ControlVar cVar_lgWaErcI;
  ControlBinop cBinop_Ti39A92l;
  ControlBinop cBinop_mftULQbM;
  ControlBinop cBinop_JHNAIITP;
  ControlTabhead cTabhead_kbp9ZY19;
  ControlVar cVar_M4Mu8DTZ;
  ControlDelay cDelay_stpocBAN;
  ControlDelay cDelay_rmGIPMZo;
  ControlBinop cBinop_rxQJoDlQ;
  ControlBinop cBinop_bwVSIcAD;
  ControlBinop cBinop_MeXgiuul;
  ControlBinop cBinop_TeFKl0Gr;
  ControlBinop cBinop_3WVb3j2c;
  ControlBinop cBinop_IFNxLmbS;
  ControlTabhead cTabhead_449Ew2Ts;
  ControlVar cVar_3BuTpOJv;
  ControlDelay cDelay_qPaX44RG;
  ControlDelay cDelay_WBCGgNnK;
  ControlBinop cBinop_TGePZbnt;
  ControlBinop cBinop_0p1CUark;
  ControlBinop cBinop_31J7JUqT;
  ControlBinop cBinop_WBLiUy5d;
  ControlBinop cBinop_orGBXCYe;
  ControlBinop cBinop_MPDzeUCk;
  ControlTabhead cTabhead_PiwKv6yL;
  ControlVar cVar_z56r03Rq;
  ControlDelay cDelay_b7Bh6mYR;
  ControlDelay cDelay_35UhAPtL;
  ControlBinop cBinop_E3xqO6mL;
  ControlBinop cBinop_Lc5xn87v;
  ControlBinop cBinop_zdIRmVsu;
  ControlBinop cBinop_ULMJGXE7;
  ControlBinop cBinop_1wWMEZpc;
  ControlBinop cBinop_bCxm5Inx;
  ControlTabhead cTabhead_8ABEGJvL;
  ControlVar cVar_nFVe3oHL;
  ControlDelay cDelay_ddw3la3Q;
  ControlDelay cDelay_kfXQmJwV;
  ControlBinop cBinop_BwgFai7f;
  ControlBinop cBinop_Bk1JzQZQ;
  ControlBinop cBinop_f83e0GhO;
  ControlBinop cBinop_6sNtGTU2;
  ControlBinop cBinop_XCOMqxAn;
  ControlBinop cBinop_ATfWsBAh;
  ControlDelay cDelay_LS97W8By;
  ControlDelay cDelay_xBxbU6sz;
  ControlBinop cBinop_XczsfHf1;
  HvTable hTable_w1CcRl7x;
  ControlBinop cBinop_zIwlgfdK;
  ControlDelay cDelay_bUPOxNzN;
  ControlDelay cDelay_3SEzDdL1;
  ControlBinop cBinop_8AGgZJej;
  HvTable hTable_HKOIdPB2;
  ControlBinop cBinop_qEbRRNpJ;
  ControlDelay cDelay_3DKaYwww;
  ControlDelay cDelay_kH02h8nS;
  ControlBinop cBinop_9b1VVm4Z;
  HvTable hTable_weaGl6kg;
  ControlBinop cBinop_A9o9Sv8J;
  ControlDelay cDelay_iurxkYN2;
  ControlDelay cDelay_qZAwpew2;
  ControlBinop cBinop_VX07xZUT;
  HvTable hTable_KwXYxzhr;
  ControlBinop cBinop_2mVSK3SS;
  ControlPack cPack_aAwZ2G0R;
  ControlPack cPack_1lRklqTL;
  ControlBinop cBinop_CGDehXv9;
  ControlBinop cBinop_VeU9oGJy;
  ControlVar cVar_Z3WHAwJW;
  ControlBinop cBinop_qQRdFZi6;
  ControlBinop cBinop_5nqLqB7q;
  SignalVarf sVarf_qpEtdoNK;
  ControlBinop cBinop_x8bXgXQR;
  ControlBinop cBinop_6qBe06N5;
  ControlBinop cBinop_eNv4FVlL;
  SignalVarf sVarf_fT3u6SEp;
  ControlVar cVar_OkpriRfd;
  ControlVar cVar_31QHT4BV;
  ControlVar cVar_XsoDXfYE;
  ControlVar cVar_C8qvgVEY;
  ControlIf cIf_03zvhVOW;
  ControlBinop cBinop_1pbcJvix;
  ControlBinop cBinop_l8G1Yp6S;
  ControlBinop cBinop_AX1IYJBw;
  ControlDelay cDelay_vWTwwCWW;
  ControlDelay cDelay_xigpHyBw;
  ControlBinop cBinop_oYIN6zcP;
  HvTable hTable_Mgmx2cg1;
  ControlBinop cBinop_Hdt6gRPI;
  ControlTabhead cTabhead_YuSMcQsu;
  ControlVar cVar_B1Hsykvz;
  ControlDelay cDelay_9F8I61nS;
  ControlDelay cDelay_XuwV73cU;
  ControlBinop cBinop_4aSSszXe;
  ControlBinop cBinop_aOHsof7v;
  ControlBinop cBinop_e21mF30h;
  ControlBinop cBinop_9iXO750v;
  ControlBinop cBinop_VCzwGXEp;
  ControlBinop cBinop_lVsWuqm8;
  ControlDelay cDelay_o3YeXRwc;
  ControlDelay cDelay_3CW05JD6;
  ControlBinop cBinop_1pWjJM4K;
  HvTable hTable_ZeJYG2Hi;
  ControlBinop cBinop_U00u69E3;
  ControlTabhead cTabhead_op7odMY5;
  ControlVar cVar_ILBjhUwg;
  ControlDelay cDelay_lhURGSVJ;
  ControlDelay cDelay_j87KPjuE;
  ControlBinop cBinop_g8bguxDn;
  ControlBinop cBinop_poZnIrzN;
  ControlBinop cBinop_72tigk5C;
  ControlBinop cBinop_f6kTTIr4;
  ControlBinop cBinop_TBwuFjj9;
  ControlBinop cBinop_ZdgpdeqX;
  ControlDelay cDelay_VMLbtWRb;
  ControlDelay cDelay_IYdRUWU6;
  ControlBinop cBinop_ztxmuUze;
  HvTable hTable_lYyPC86n;
  ControlBinop cBinop_2xl5tLlM;
  ControlTabhead cTabhead_yXkPKi2m;
  ControlVar cVar_A7pJbzQa;
  ControlDelay cDelay_xEZCqDTI;
  ControlDelay cDelay_CoMl2W8a;
  ControlBinop cBinop_eFiSLxHm;
  ControlBinop cBinop_T5iYSDbs;
  ControlBinop cBinop_oUVYyPCD;
  ControlBinop cBinop_ARR0OOu3;
  ControlBinop cBinop_Hk4onTfs;
  ControlBinop cBinop_djnk99Lw;
  ControlDelay cDelay_D6m5cNat;
  ControlDelay cDelay_BLmR09sr;
  ControlBinop cBinop_U36FebgB;
  HvTable hTable_3tlLcWtp;
  ControlBinop cBinop_iyCFQCi7;
  ControlTabhead cTabhead_hXO3fcjJ;
  ControlVar cVar_AaIFL8LU;
  ControlDelay cDelay_q40AgYgm;
  ControlDelay cDelay_79HrYtyk;
  ControlBinop cBinop_8AKgWEzW;
  ControlBinop cBinop_nak7MDfD;
  ControlBinop cBinop_IXZH2jZ7;
  ControlBinop cBinop_i8FMYRvg;
  ControlBinop cBinop_fmYxIzOs;
  ControlBinop cBinop_SgAts0sa;
  ControlDelay cDelay_94epppIb;
  ControlDelay cDelay_5QTRdoNJ;
  ControlBinop cBinop_dPaTGo6A;
  HvTable hTable_dj8UlpVj;
  ControlBinop cBinop_Nj4xJwSZ;
  ControlTabhead cTabhead_K7RyFZAL;
  ControlVar cVar_GneM7Q8c;
  ControlDelay cDelay_Ho8NhQA0;
  ControlDelay cDelay_TWeYqmWR;
  ControlBinop cBinop_HgiWsFA4;
  ControlBinop cBinop_qvRGAajQ;
  ControlBinop cBinop_aPmenPrI;
  ControlBinop cBinop_3uxHStoW;
  ControlBinop cBinop_cVgfJjiD;
  ControlBinop cBinop_w78IkyqI;
  ControlDelay cDelay_b3aiNhHx;
  ControlDelay cDelay_BZ1wUFvM;
  ControlBinop cBinop_UyDhV6Ic;
  HvTable hTable_Hbzr2HCW;
  ControlBinop cBinop_XsIvhF82;
  ControlTabhead cTabhead_1W4hWoEC;
  ControlVar cVar_LLwKJ2DY;
  ControlDelay cDelay_nOOb54TS;
  ControlDelay cDelay_OB5HtwN1;
  ControlBinop cBinop_qCtb4Zrt;
  ControlBinop cBinop_3dOebfph;
  ControlBinop cBinop_RFsc2eLb;
  ControlBinop cBinop_hz0tCc6n;
  ControlBinop cBinop_HFpTnaro;
  ControlBinop cBinop_Boq9Tgqi;
  ControlVar cVar_7eIZrsrH;
  ControlVar cVar_e4QjC6qu;
  ControlPack cPack_92Qv8Xf2;
  ControlVar cVar_0vY0zf7a;
  ControlBinop cBinop_6X9HX5j9;
  ControlBinop cBinop_ymRtxmk5;
  SignalVarf sVarf_Cy93JAJg;
  ControlBinop cBinop_LGjKBMbH;
  ControlBinop cBinop_Qyi0torp;
  ControlBinop cBinop_dxZ8zMSM;
  SignalVarf sVarf_KQ7zHV9X;
  ControlVar cVar_lMcABg8R;
  ControlBinop cBinop_2uQu6Hod;
  ControlBinop cBinop_Pth6FFBK;
  SignalVarf sVarf_tiUtzi2h;
  ControlBinop cBinop_au7CcuuU;
  ControlBinop cBinop_pndV2h7o;
  ControlBinop cBinop_ZHIvFy7I;
  SignalVarf sVarf_XOrJk30h;
  ControlVar cVar_Xn3p4Wkh;
  ControlBinop cBinop_L60BcJrr;
  ControlBinop cBinop_3cTGmh13;
  SignalVarf sVarf_SlMUDRHI;
  ControlBinop cBinop_pkBXYrLR;
  ControlBinop cBinop_f6PYrP4o;
  ControlBinop cBinop_xzfwI5cO;
  SignalVarf sVarf_9SvE3brO;
  ControlBinop cBinop_zRaqiAKp;
  ControlBinop cBinop_5L4J4gc2;
  ControlBinop cBinop_TsMSpxl0;
  ControlDelay cDelay_HNplLjy3;
  ControlVar cVar_f7BAu6ZJ;
  ControlBinop cBinop_adYdiZ7w;
  ControlBinop cBinop_q9i6AyN6;
  ControlBinop cBinop_JKdNGvrL;
  ControlVar cVar_SAYtVUv1;
  ControlVar cVar_pF57YmUH;
  ControlIf cIf_qT3VR0vL;
  ControlBinop cBinop_SfyQIaZB;
  ControlDelay cDelay_VkkHeLhM;
  ControlDelay cDelay_EevCCH2a;
  ControlBinop cBinop_uvLFGQ3o;
  HvTable hTable_mIAgTbtp;
  ControlBinop cBinop_oR9Gieiy;
  ControlTabhead cTabhead_AW2BhyNt;
  ControlVar cVar_Gc8KXJNQ;
  ControlDelay cDelay_Cfx6xCKw;
  ControlDelay cDelay_2E1gdxeO;
  ControlBinop cBinop_VXcbu3Ru;
  ControlBinop cBinop_h5KUEZwU;
  ControlBinop cBinop_jkXtgQKc;
  ControlBinop cBinop_gdYpZGuD;
  ControlBinop cBinop_4bURRFJP;
  ControlBinop cBinop_kKwhalB9;
  ControlVar cVar_rUdcJEEk;
  ControlVar cVar_Aczh8Mxg;
  ControlVar cVar_PUENAyhw;
  ControlVar cVar_MvNbwmLS;
  ControlVar cVar_NB9wU9AZ;
  ControlVar cVar_y55JL9rC;
  ControlIf cIf_Zbj0HRP7;
  ControlBinop cBinop_0YOE2q0s;
  ControlVar cVar_UMf3Fzz0;
  ControlIf cIf_LqqQlWl9;
  ControlBinop cBinop_ihjzmfs7;
  ControlSlice cSlice_KZOiJutY;
  ControlSlice cSlice_5ULcDOyj;
  ControlVar cVar_I3HTsRbZ;
  ControlIf cIf_0v7mHeNz;
  ControlBinop cBinop_N2xN9SWn;
  ControlIf cIf_pgEnseIu;
  ControlIf cIf_uHXb7ajr;
  ControlIf cIf_tnSToyym;
  ControlIf cIf_MCiLUuLp;
  ControlIf cIf_kZycz411;
  SignalVarf sVarf_v0vQWkq4;
  ControlBinop cBinop_FWtEicuA;
  ControlBinop cBinop_7ToFA9Mp;
  ControlBinop cBinop_5m8wKrhQ;
  ControlBinop cBinop_OkqMvj7h;
  SignalVarf sVarf_xJtE774L;
  ControlBinop cBinop_4qzR92CY;
  ControlBinop cBinop_odsxXNxf;
  SignalVarf sVarf_prxQkkA7;
  SignalVarf sVarf_bFUcLZ3z;
  ControlBinop cBinop_52oE43aW;
  ControlBinop cBinop_wnWsOMms;
  ControlBinop cBinop_dJQGhVrX;
  ControlBinop cBinop_TCLuiTMf;
  ControlBinop cBinop_2Cg2NSuh;
  ControlBinop cBinop_XKT11r1t;
  ControlBinop cBinop_NKNY9KJ6;
  ControlBinop cBinop_yuePTcK4;
  ControlBinop cBinop_Oy9gjPeE;
  ControlBinop cBinop_kRf6c3VH;
  ControlBinop cBinop_saqSZLmF;
  ControlBinop cBinop_q7WcSV8S;
  ControlBinop cBinop_VcSU2W1F;
};

#endif // _HEAVY_CONTEXT_CHAFFVERB_HPP_
