/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_ChaffVerb.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_ChaffVerb *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_ChaffVerb_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_ChaffVerb();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_ChaffVerb::Heavy_ChaffVerb(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sPhasor_k_init(&sPhasor_Ax5YbSyP, 0.0f, sampleRate);
  numBytes += sLine_init(&sLine_0Y24QhQj);
  numBytes += sLine_init(&sLine_7ps0Bip1);
  numBytes += sTabhead_init(&sTabhead_TJQykQGL, &hTable_WO4aRDpi);
  numBytes += sTabread_init(&sTabread_nFb8TAAo, &hTable_WO4aRDpi, false);
  numBytes += sTabread_init(&sTabread_6CYHAJbK, &hTable_WO4aRDpi, false);
  numBytes += sTabhead_init(&sTabhead_zzHC3LEB, &hTable_WO4aRDpi);
  numBytes += sTabread_init(&sTabread_kmq1R0Op, &hTable_WO4aRDpi, false);
  numBytes += sTabread_init(&sTabread_3wYqntri, &hTable_WO4aRDpi, false);
  numBytes += sTabwrite_init(&sTabwrite_KMUQLhrV, &hTable_WO4aRDpi);
  numBytes += sRPole_init(&sRPole_zSznCkul);
  numBytes += sDel1_init(&sDel1_t6GtLLlE);
  numBytes += sTabread_init(&sTabread_Z2Rs1L7l, &hTable_mIAgTbtp, true);
  numBytes += sTabwrite_init(&sTabwrite_LJaFtyr9, &hTable_mIAgTbtp);
  numBytes += sTabread_init(&sTabread_voxtaPEX, &hTable_w1CcRl7x, true);
  numBytes += sRPole_init(&sRPole_FiKuGxU7);
  numBytes += sLine_init(&sLine_GQDNNPqU);
  numBytes += sLine_init(&sLine_KzGWmAVR);
  numBytes += sTabread_init(&sTabread_yTfcWTOF, &hTable_Mgmx2cg1, true);
  numBytes += sTabread_init(&sTabread_gc69BEPk, &hTable_ZeJYG2Hi, true);
  numBytes += sTabread_init(&sTabread_jd8v8eTI, &hTable_lYyPC86n, true);
  numBytes += sTabread_init(&sTabread_afV6PBIq, &hTable_3tlLcWtp, true);
  numBytes += sTabread_init(&sTabread_D5pz8pIq, &hTable_Hbzr2HCW, true);
  numBytes += sTabread_init(&sTabread_l34qTGku, &hTable_dj8UlpVj, true);
  numBytes += sTabwrite_init(&sTabwrite_xvcTTCIt, &hTable_Mgmx2cg1);
  numBytes += sTabwrite_init(&sTabwrite_8WxOzIRJ, &hTable_ZeJYG2Hi);
  numBytes += sTabwrite_init(&sTabwrite_f1b2SbLs, &hTable_lYyPC86n);
  numBytes += sTabwrite_init(&sTabwrite_KVZuN0wL, &hTable_3tlLcWtp);
  numBytes += sTabwrite_init(&sTabwrite_eK1EKK8w, &hTable_dj8UlpVj);
  numBytes += sTabwrite_init(&sTabwrite_jvWti33b, &hTable_Hbzr2HCW);
  numBytes += sTabread_init(&sTabread_ctLULMbY, &hTable_HKOIdPB2, true);
  numBytes += sRPole_init(&sRPole_gq8w1ZlP);
  numBytes += sTabread_init(&sTabread_Bwo6FKNV, &hTable_weaGl6kg, true);
  numBytes += sRPole_init(&sRPole_mVmkmH1I);
  numBytes += sTabread_init(&sTabread_we43Zb4Y, &hTable_KwXYxzhr, true);
  numBytes += sRPole_init(&sRPole_XML0uIro);
  numBytes += sTabwrite_init(&sTabwrite_eF3lDk9I, &hTable_w1CcRl7x);
  numBytes += sTabwrite_init(&sTabwrite_H2DgVUXc, &hTable_HKOIdPB2);
  numBytes += sTabwrite_init(&sTabwrite_c0Yu9ky1, &hTable_weaGl6kg);
  numBytes += sTabwrite_init(&sTabwrite_GzhOi7Ay, &hTable_KwXYxzhr);
  numBytes += sLine_init(&sLine_sKtHIecZ);
  numBytes += cVar_init_f(&cVar_OPQeRErB, 0.0f);
  numBytes += cVar_init_f(&cVar_FAV62Nt6, 0.0f);
  numBytes += cPack_init(&cPack_sukqSXO8, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_fBy4WdvJ, 0.0f);
  numBytes += cPack_init(&cPack_LqWGzCsE, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_oPSXzheC, 0.0f);
  numBytes += cVar_init_f(&cVar_ZBMUVoDH, 0.0f);
  numBytes += cDelay_init(this, &cDelay_UNNOp1B7, 0.0f);
  numBytes += cDelay_init(this, &cDelay_BQyZVYx0, 0.0f);
  numBytes += hTable_init(&hTable_WO4aRDpi, 256);
  numBytes += cVar_init_s(&cVar_JuBjlJal, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_8y7lEkG8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ikhkn92g, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_O01VgdzB, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_b3JViUzi, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_47rxuoI7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_riZcPc92, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LiUUr7W1, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_qSLPkcOX, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_8W9GCEti, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_uvHpYS5q, 0.0f);
  numBytes += cBinop_init(&cBinop_DS6vahZU, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_4Jr7TZZR, 0.0f, 0.0f, false);
  numBytes += cRandom_init(&cRandom_uZGlEot1, 68849329);
  numBytes += cSlice_init(&cSlice_r9iMewng, 1, 1);
  numBytes += cDelay_init(this, &cDelay_8r6cMHUH, 0.0f);
  numBytes += cVar_init_f(&cVar_lgWaErcI, 5.0f);
  numBytes += cBinop_init(&cBinop_JHNAIITP, 0.0f); // __mul
  numBytes += cTabhead_init(&cTabhead_kbp9ZY19, &hTable_w1CcRl7x);
  numBytes += cVar_init_s(&cVar_M4Mu8DTZ, "del-1052-del1");
  numBytes += cDelay_init(this, &cDelay_stpocBAN, 58.6435f);
  numBytes += cDelay_init(this, &cDelay_rmGIPMZo, 0.0f);
  numBytes += cBinop_init(&cBinop_rxQJoDlQ, 58.6435f); // __mul
  numBytes += cBinop_init(&cBinop_MeXgiuul, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_TeFKl0Gr, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_IFNxLmbS, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_449Ew2Ts, &hTable_HKOIdPB2);
  numBytes += cVar_init_s(&cVar_3BuTpOJv, "del-1052-del2");
  numBytes += cDelay_init(this, &cDelay_qPaX44RG, 69.4325f);
  numBytes += cDelay_init(this, &cDelay_WBCGgNnK, 0.0f);
  numBytes += cBinop_init(&cBinop_TGePZbnt, 69.4325f); // __mul
  numBytes += cBinop_init(&cBinop_31J7JUqT, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_WBLiUy5d, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_MPDzeUCk, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_PiwKv6yL, &hTable_weaGl6kg);
  numBytes += cVar_init_s(&cVar_z56r03Rq, "del-1052-del3");
  numBytes += cDelay_init(this, &cDelay_b7Bh6mYR, 74.5234f);
  numBytes += cDelay_init(this, &cDelay_35UhAPtL, 0.0f);
  numBytes += cBinop_init(&cBinop_E3xqO6mL, 74.5234f); // __mul
  numBytes += cBinop_init(&cBinop_zdIRmVsu, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_ULMJGXE7, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_bCxm5Inx, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_8ABEGJvL, &hTable_KwXYxzhr);
  numBytes += cVar_init_s(&cVar_nFVe3oHL, "del-1052-del4");
  numBytes += cDelay_init(this, &cDelay_ddw3la3Q, 86.1244f);
  numBytes += cDelay_init(this, &cDelay_kfXQmJwV, 0.0f);
  numBytes += cBinop_init(&cBinop_BwgFai7f, 86.1244f); // __mul
  numBytes += cBinop_init(&cBinop_f83e0GhO, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_6sNtGTU2, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_ATfWsBAh, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_LS97W8By, 0.0f);
  numBytes += cDelay_init(this, &cDelay_xBxbU6sz, 0.0f);
  numBytes += hTable_init(&hTable_w1CcRl7x, 256);
  numBytes += cDelay_init(this, &cDelay_bUPOxNzN, 0.0f);
  numBytes += cDelay_init(this, &cDelay_3SEzDdL1, 0.0f);
  numBytes += hTable_init(&hTable_HKOIdPB2, 256);
  numBytes += cDelay_init(this, &cDelay_3DKaYwww, 0.0f);
  numBytes += cDelay_init(this, &cDelay_kH02h8nS, 0.0f);
  numBytes += hTable_init(&hTable_weaGl6kg, 256);
  numBytes += cDelay_init(this, &cDelay_iurxkYN2, 0.0f);
  numBytes += cDelay_init(this, &cDelay_qZAwpew2, 0.0f);
  numBytes += hTable_init(&hTable_KwXYxzhr, 256);
  numBytes += cPack_init(&cPack_aAwZ2G0R, 2, 0.0f, 30.0f);
  numBytes += cPack_init(&cPack_1lRklqTL, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_Z3WHAwJW, 22050.0f);
  numBytes += cBinop_init(&cBinop_qQRdFZi6, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_qpEtdoNK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fT3u6SEp, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_OkpriRfd, 0.0f);
  numBytes += cVar_init_f(&cVar_31QHT4BV, 0.0f);
  numBytes += cVar_init_f(&cVar_XsoDXfYE, 0.0f);
  numBytes += cVar_init_f(&cVar_C8qvgVEY, 0.0f);
  numBytes += cIf_init(&cIf_03zvhVOW, false);
  numBytes += cDelay_init(this, &cDelay_vWTwwCWW, 0.0f);
  numBytes += cDelay_init(this, &cDelay_xigpHyBw, 0.0f);
  numBytes += hTable_init(&hTable_Mgmx2cg1, 256);
  numBytes += cTabhead_init(&cTabhead_YuSMcQsu, &hTable_Mgmx2cg1);
  numBytes += cVar_init_s(&cVar_B1Hsykvz, "del-1052-ref1");
  numBytes += cDelay_init(this, &cDelay_9F8I61nS, 43.5337f);
  numBytes += cDelay_init(this, &cDelay_XuwV73cU, 0.0f);
  numBytes += cBinop_init(&cBinop_4aSSszXe, 43.5337f); // __mul
  numBytes += cBinop_init(&cBinop_e21mF30h, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_9iXO750v, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_lVsWuqm8, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_o3YeXRwc, 0.0f);
  numBytes += cDelay_init(this, &cDelay_3CW05JD6, 0.0f);
  numBytes += hTable_init(&hTable_ZeJYG2Hi, 256);
  numBytes += cTabhead_init(&cTabhead_op7odMY5, &hTable_ZeJYG2Hi);
  numBytes += cVar_init_s(&cVar_ILBjhUwg, "del-1052-ref2");
  numBytes += cDelay_init(this, &cDelay_lhURGSVJ, 25.796f);
  numBytes += cDelay_init(this, &cDelay_j87KPjuE, 0.0f);
  numBytes += cBinop_init(&cBinop_g8bguxDn, 25.796f); // __mul
  numBytes += cBinop_init(&cBinop_72tigk5C, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_f6kTTIr4, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_ZdgpdeqX, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_VMLbtWRb, 0.0f);
  numBytes += cDelay_init(this, &cDelay_IYdRUWU6, 0.0f);
  numBytes += hTable_init(&hTable_lYyPC86n, 256);
  numBytes += cTabhead_init(&cTabhead_yXkPKi2m, &hTable_lYyPC86n);
  numBytes += cVar_init_s(&cVar_A7pJbzQa, "del-1052-ref3");
  numBytes += cDelay_init(this, &cDelay_xEZCqDTI, 19.392f);
  numBytes += cDelay_init(this, &cDelay_CoMl2W8a, 0.0f);
  numBytes += cBinop_init(&cBinop_eFiSLxHm, 19.392f); // __mul
  numBytes += cBinop_init(&cBinop_oUVYyPCD, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_ARR0OOu3, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_djnk99Lw, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_D6m5cNat, 0.0f);
  numBytes += cDelay_init(this, &cDelay_BLmR09sr, 0.0f);
  numBytes += hTable_init(&hTable_3tlLcWtp, 256);
  numBytes += cTabhead_init(&cTabhead_hXO3fcjJ, &hTable_3tlLcWtp);
  numBytes += cVar_init_s(&cVar_AaIFL8LU, "del-1052-ref4");
  numBytes += cDelay_init(this, &cDelay_q40AgYgm, 16.364f);
  numBytes += cDelay_init(this, &cDelay_79HrYtyk, 0.0f);
  numBytes += cBinop_init(&cBinop_8AKgWEzW, 16.364f); // __mul
  numBytes += cBinop_init(&cBinop_IXZH2jZ7, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_i8FMYRvg, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_SgAts0sa, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_94epppIb, 0.0f);
  numBytes += cDelay_init(this, &cDelay_5QTRdoNJ, 0.0f);
  numBytes += hTable_init(&hTable_dj8UlpVj, 256);
  numBytes += cTabhead_init(&cTabhead_K7RyFZAL, &hTable_dj8UlpVj);
  numBytes += cVar_init_s(&cVar_GneM7Q8c, "del-1052-ref6");
  numBytes += cDelay_init(this, &cDelay_Ho8NhQA0, 4.2546f);
  numBytes += cDelay_init(this, &cDelay_TWeYqmWR, 0.0f);
  numBytes += cBinop_init(&cBinop_HgiWsFA4, 4.2546f); // __mul
  numBytes += cBinop_init(&cBinop_aPmenPrI, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_3uxHStoW, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_w78IkyqI, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_b3aiNhHx, 0.0f);
  numBytes += cDelay_init(this, &cDelay_BZ1wUFvM, 0.0f);
  numBytes += hTable_init(&hTable_Hbzr2HCW, 256);
  numBytes += cTabhead_init(&cTabhead_1W4hWoEC, &hTable_Hbzr2HCW);
  numBytes += cVar_init_s(&cVar_LLwKJ2DY, "del-1052-ref5");
  numBytes += cDelay_init(this, &cDelay_nOOb54TS, 7.645f);
  numBytes += cDelay_init(this, &cDelay_OB5HtwN1, 0.0f);
  numBytes += cBinop_init(&cBinop_qCtb4Zrt, 7.645f); // __mul
  numBytes += cBinop_init(&cBinop_RFsc2eLb, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_hz0tCc6n, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_Boq9Tgqi, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_7eIZrsrH, 0.0f);
  numBytes += cVar_init_f(&cVar_e4QjC6qu, 0.0f);
  numBytes += cPack_init(&cPack_92Qv8Xf2, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_0vY0zf7a, 22050.0f);
  numBytes += cBinop_init(&cBinop_6X9HX5j9, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Cy93JAJg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KQ7zHV9X, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_lMcABg8R, 22050.0f);
  numBytes += cBinop_init(&cBinop_2uQu6Hod, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_tiUtzi2h, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XOrJk30h, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Xn3p4Wkh, 22050.0f);
  numBytes += cBinop_init(&cBinop_L60BcJrr, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_SlMUDRHI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9SvE3brO, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_HNplLjy3, 0.0f);
  numBytes += cVar_init_f(&cVar_f7BAu6ZJ, 1000.0f);
  numBytes += cBinop_init(&cBinop_JKdNGvrL, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_SAYtVUv1, 0.0f);
  numBytes += cVar_init_f(&cVar_pF57YmUH, 0.0f);
  numBytes += cIf_init(&cIf_qT3VR0vL, false);
  numBytes += cDelay_init(this, &cDelay_VkkHeLhM, 0.0f);
  numBytes += cDelay_init(this, &cDelay_EevCCH2a, 0.0f);
  numBytes += hTable_init(&hTable_mIAgTbtp, 256);
  numBytes += cTabhead_init(&cTabhead_AW2BhyNt, &hTable_mIAgTbtp);
  numBytes += cVar_init_s(&cVar_Gc8KXJNQ, "del-1001-del1");
  numBytes += cDelay_init(this, &cDelay_Cfx6xCKw, 150.0f);
  numBytes += cDelay_init(this, &cDelay_2E1gdxeO, 0.0f);
  numBytes += cBinop_init(&cBinop_VXcbu3Ru, 150.0f); // __mul
  numBytes += cBinop_init(&cBinop_jkXtgQKc, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_gdYpZGuD, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_kKwhalB9, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_rUdcJEEk, 0.0f);
  numBytes += cVar_init_f(&cVar_Aczh8Mxg, 0.0f);
  numBytes += cVar_init_f(&cVar_PUENAyhw, 0.0f);
  numBytes += cVar_init_f(&cVar_MvNbwmLS, 0.0f);
  numBytes += cVar_init_f(&cVar_NB9wU9AZ, 0.0f);
  numBytes += cVar_init_f(&cVar_y55JL9rC, 0.0f);
  numBytes += cIf_init(&cIf_Zbj0HRP7, false);
  numBytes += cVar_init_f(&cVar_UMf3Fzz0, 0.0f);
  numBytes += cIf_init(&cIf_LqqQlWl9, false);
  numBytes += cSlice_init(&cSlice_KZOiJutY, 1, -1);
  numBytes += cSlice_init(&cSlice_5ULcDOyj, 1, -1);
  numBytes += cVar_init_f(&cVar_I3HTsRbZ, 0.0f);
  numBytes += cIf_init(&cIf_0v7mHeNz, false);
  numBytes += cBinop_init(&cBinop_N2xN9SWn, 0.0f); // __neq
  numBytes += cIf_init(&cIf_pgEnseIu, false);
  numBytes += cIf_init(&cIf_uHXb7ajr, false);
  numBytes += cIf_init(&cIf_tnSToyym, false);
  numBytes += cIf_init(&cIf_MCiLUuLp, true);
  numBytes += cIf_init(&cIf_kZycz411, false);
  numBytes += sVarf_init(&sVarf_v0vQWkq4, 1.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_5m8wKrhQ, 4.0f); // __unimod
  numBytes += sVarf_init(&sVarf_xJtE774L, 0.1f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_4qzR92CY, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_odsxXNxf, 0.0f); // __add
  numBytes += sVarf_init(&sVarf_prxQkkA7, 0.65f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bFUcLZ3z, 0.55f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_wnWsOMms, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_Oy9gjPeE, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_kRf6c3VH, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_saqSZLmF, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_q7WcSV8S, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_VcSU2W1F, 0.0f); // __add
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_ChaffVerb::~Heavy_ChaffVerb() {
  cPack_free(&cPack_sukqSXO8);
  cPack_free(&cPack_LqWGzCsE);
  hTable_free(&hTable_WO4aRDpi);
  hTable_free(&hTable_w1CcRl7x);
  hTable_free(&hTable_HKOIdPB2);
  hTable_free(&hTable_weaGl6kg);
  hTable_free(&hTable_KwXYxzhr);
  cPack_free(&cPack_aAwZ2G0R);
  cPack_free(&cPack_1lRklqTL);
  hTable_free(&hTable_Mgmx2cg1);
  hTable_free(&hTable_ZeJYG2Hi);
  hTable_free(&hTable_lYyPC86n);
  hTable_free(&hTable_3tlLcWtp);
  hTable_free(&hTable_dj8UlpVj);
  hTable_free(&hTable_Hbzr2HCW);
  cPack_free(&cPack_92Qv8Xf2);
  hTable_free(&hTable_mIAgTbtp);
}

HvTable *Heavy_ChaffVerb::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xA1445E2C: return &hTable_WO4aRDpi; // del-1002-shifter
    case 0xAAA0EB60: return &hTable_w1CcRl7x; // del-1052-del1
    case 0xA2AC524D: return &hTable_HKOIdPB2; // del-1052-del2
    case 0xE36A35B: return &hTable_weaGl6kg; // del-1052-del3
    case 0x48CE0509: return &hTable_KwXYxzhr; // del-1052-del4
    case 0xE34D6E72: return &hTable_Mgmx2cg1; // del-1052-ref1
    case 0x6A1027AB: return &hTable_ZeJYG2Hi; // del-1052-ref2
    case 0xA37C6D49: return &hTable_lYyPC86n; // del-1052-ref3
    case 0xCEFE5FE5: return &hTable_3tlLcWtp; // del-1052-ref4
    case 0x48EB8BBB: return &hTable_dj8UlpVj; // del-1052-ref6
    case 0xCC6F73D5: return &hTable_Hbzr2HCW; // del-1052-ref5
    case 0xED65564F: return &hTable_mIAgTbtp; // del-1001-del1
    default: return nullptr;
  }
}

void Heavy_ChaffVerb::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x1F30993F: { // A__LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_POY7rgSw_sendMessage);
      break;
    }
    case 0x1A2B8E9F: { // A__LFO_Steps_Scale__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Qc3Z9Elh_sendMessage);
      break;
    }
    case 0xBE3344C8: { // A__LFO_Steps__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pT7y5Ca9_sendMessage);
      break;
    }
    case 0x7369936E: { // A__LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_78PT4LC8_sendMessage);
      break;
    }
    case 0xD64CFD23: { // A__LFO_type
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Wn4pB0Ij_sendMessage);
      break;
    }
    case 0x51447E19: { // B__General_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_p7Uc0oSo_sendMessage);
      break;
    }
    case 0xA10FCFC4: { // B__General_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LZy5LsT4_sendMessage);
      break;
    }
    case 0x7EFB8E46: { // C__Random_LFO_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Qii7GLtr_sendMessage);
      break;
    }
    case 0xE6223016: { // C__Random_LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fGelSoQ3_sendMessage);
      break;
    }
    case 0x3281900D: { // C__Random_LFO_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P1ZphNSi_sendMessage);
      break;
    }
    case 0x6150BC53: { // C__Random_LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ddR4PL4V_sendMessage);
      break;
    }
    case 0x9CBB1BF3: { // D__Shift_Microtone
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GRvxiMYi_sendMessage);
      break;
    }
    case 0x4439D71: { // D__Shift_Transpose
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Fznjw77K_sendMessage);
      break;
    }
    case 0x890283C2: { // E__Fx_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rl9L58y3_sendMessage);
      break;
    }
    case 0x12962685: { // E__HiPass_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5vIIEspB_sendMessage);
      break;
    }
    case 0x183CFEE5: { // E__Shift_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_59frYoOB_sendMessage);
      break;
    }
    case 0x57FF40DB: { // E__Shift_Window
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_o6othANf_sendMessage);
      break;
    }
    case 0x69A91334: { // F__FX_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BIqY4UwO_sendMessage);
      break;
    }
    case 0x68D029F7: { // F__FX_Delay_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DCDg1hWC_sendMessage);
      break;
    }
    case 0xD63693D0: { // Mix__Dry_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OiEPzm9Z_sendMessage);
      break;
    }
    case 0x1FC3C02C: { // Mix__Dry_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9Q9WIloS_sendMessage);
      break;
    }
    case 0x58653D84: { // Mix__Reverb_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RslN4wDl_sendMessage);
      break;
    }
    case 0xE764F673: { // Mix__Reverb_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qpVwdLES_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_E2RHRskd_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_ChaffVerb::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "A__LFO_Period";
        info->hash = 0x1F30993F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 1: {
        info->name = "A__LFO_Steps_Scale__Type2";
        info->hash = 0x1A2B8E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -5.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "A__LFO_Steps__Type2";
        info->hash = 0xBE3344C8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 10.0f;
        info->defaultVal = 4.0f;
        break;
      }
      case 3: {
        info->name = "A__LFO_Switch";
        info->hash = 0x7369936E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "A__LFO_type";
        info->hash = 0xD64CFD23;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2.99f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "B__General_Offset";
        info->hash = 0x51447E19;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "B__General_Scale";
        info->hash = 0xA10FCFC4;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "C__Random_LFO_Offset";
        info->hash = 0x7EFB8E46;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "C__Random_LFO_Period";
        info->hash = 0xE6223016;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 9: {
        info->name = "C__Random_LFO_Scale";
        info->hash = 0x3281900D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "C__Random_LFO_Switch";
        info->hash = 0x6150BC53;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "D__Shift_Microtone";
        info->hash = 0x9CBB1BF3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -1.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "D__Shift_Transpose";
        info->hash = 0x4439D71;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -36.0f;
        info->maxVal = 36.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "E__Fx_Level";
        info->hash = 0x890283C2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.7f;
        break;
      }
      case 14: {
        info->name = "E__HiPass_Freq";
        info->hash = 0x12962685;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 100.0f;
        info->maxVal = 2500.0f;
        info->defaultVal = 800.0f;
        break;
      }
      case 15: {
        info->name = "E__Shift_Delay";
        info->hash = 0x183CFEE5;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 500.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "E__Shift_Window";
        info->hash = 0x57FF40DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 3500.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 17: {
        info->name = "F__FX_Delay";
        info->hash = 0x69A91334;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 18: {
        info->name = "F__FX_Delay_Feedback";
        info->hash = 0x68D029F7;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.97f;
        info->defaultVal = 0.65f;
        break;
      }
      case 19: {
        info->name = "Mix__Dry_Mix";
        info->hash = 0xD63693D0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.45f;
        break;
      }
      case 20: {
        info->name = "Mix__Dry_Vol";
        info->hash = 0x1FC3C02C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.1f;
        break;
      }
      case 21: {
        info->name = "Mix__Reverb_Level";
        info->hash = 0x58653D84;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.85f;
        break;
      }
      case 22: {
        info->name = "Mix__Reverb_Vol";
        info->hash = 0xE764F673;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.5f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 23;
}



/*
 * Send Function Implementations
 */


void Heavy_ChaffVerb::cVar_OPQeRErB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.05776f, 0, m, &cBinop_chKxkxdZ_sendMessage);
}

void Heavy_ChaffVerb::cVar_FAV62Nt6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_zc6ynir8_sendMessage);
}

void Heavy_ChaffVerb::cPack_sukqSXO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_0Y24QhQj, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_KGcHUblS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fBy4WdvJ, 0, m, &cVar_fBy4WdvJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3jlHPp8k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_EXP, m, &cUnop_KGcHUblS_sendMessage);
}

void Heavy_ChaffVerb::cVar_fBy4WdvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pABrkwVo_sendMessage);
}

void Heavy_ChaffVerb::cPack_LqWGzCsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_7ps0Bip1, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_oPSXzheC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.5f, 0, m, &cBinop_gWCIf3SK_sendMessage);
}

void Heavy_ChaffVerb::cVar_ZBMUVoDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_Ax5YbSyP, 0, m);
}

void Heavy_ChaffVerb::cMsg_c04O9FAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BHv5HJGU_sendMessage);
}

void Heavy_ChaffVerb::cSystem_BHv5HJGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_FRTzLqfP_sendMessage);
}

void Heavy_ChaffVerb::cDelay_UNNOp1B7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UNNOp1B7, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BQyZVYx0, 0, m, &cDelay_BQyZVYx0_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UNNOp1B7, 0, m, &cDelay_UNNOp1B7_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_KMUQLhrV, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_BQyZVYx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BQyZVYx0, m);
  cMsg_jfU8iXJz_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_iceV1m1l_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_MZ0L4o4I_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_WJQ006H4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nDI5NM33_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_WO4aRDpi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JpwPkkZz_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UNNOp1B7, 2, m, &cDelay_UNNOp1B7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_foXuA8oP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nDI5NM33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_WO4aRDpi, 0, m, &hTable_WO4aRDpi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_FRTzLqfP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_WJQ006H4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jfU8iXJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_WO4aRDpi, 0, m, &hTable_WO4aRDpi_sendMessage);
}

void Heavy_ChaffVerb::cCast_foXuA8oP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UNNOp1B7, 0, m, &cDelay_UNNOp1B7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JpwPkkZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_BQyZVYx0, 2, m, &cDelay_BQyZVYx0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MZ0L4o4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_KMUQLhrV, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_Xqn0GULS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_z3BsGTPI_sendMessage);
}

void Heavy_ChaffVerb::cSystem_z3BsGTPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_5dLhfxh4_sendMessage);
}

void Heavy_ChaffVerb::cVar_JuBjlJal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A3wTl2VW_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_QjxsqlMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_11VltUxw_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_8y7lEkG8, m);
}

void Heavy_ChaffVerb::cBinop_5dLhfxh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ikhkn92g, m);
}

void Heavy_ChaffVerb::cMsg_A3wTl2VW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QjxsqlMl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_11VltUxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_O01VgdzB, m);
}

void Heavy_ChaffVerb::cMsg_7w1Yx4dk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_v4AaPl24_sendMessage);
}

void Heavy_ChaffVerb::cSystem_v4AaPl24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_GFavBSq9_sendMessage);
}

void Heavy_ChaffVerb::cVar_b3JViUzi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bqlSdahY_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_1vsnJLD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_AUUa2wof_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_47rxuoI7, m);
}

void Heavy_ChaffVerb::cBinop_GFavBSq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_riZcPc92, m);
}

void Heavy_ChaffVerb::cMsg_bqlSdahY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1vsnJLD3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_AUUa2wof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_LiUUr7W1, m);
}

void Heavy_ChaffVerb::cBinop_qSLPkcOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZBMUVoDH, 0, m, &cVar_ZBMUVoDH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_EAuMAasL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kSCZv2NK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8mtA9MyH_sendMessage);
}

void Heavy_ChaffVerb::cCast_8mtA9MyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qSLPkcOX, HV_BINOP_DIVIDE, 0, m, &cBinop_qSLPkcOX_sendMessage);
}

void Heavy_ChaffVerb::cCast_kSCZv2NK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qSLPkcOX, HV_BINOP_DIVIDE, 1, m, &cBinop_qSLPkcOX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pABrkwVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_zErhscQE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_chKxkxdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 87.3365f, 0, m, &cBinop_3jlHPp8k_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zErhscQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qSLPkcOX, HV_BINOP_DIVIDE, 0, m, &cBinop_qSLPkcOX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gWCIf3SK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_LqWGzCsE, 0, m, &cPack_LqWGzCsE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zc6ynir8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.001f, 0, m, &cBinop_EAuMAasL_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_sukqSXO8, 0, m, &cPack_sukqSXO8_sendMessage);
}

void Heavy_ChaffVerb::cUnop_zhXivI55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uHXb7ajr, 0, m, &cIf_uHXb7ajr_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_4Oj7Hbe5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ni7AxIO1_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ARV5ZP2E_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xEKb1F84_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_ni7AxIO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BUX5Ftml_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_ARV5ZP2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lq3iT8P4_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_xEKb1F84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tpPFnysf_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_3wr1fDK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_eR07JfjL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_eR07JfjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_0HicDVWX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_CoDZvMac_sendMessage);
}

void Heavy_ChaffVerb::cVar_uvHpYS5q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_jRXx53AA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GXQSexDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dNjRU3xi_sendMessage);
}

void Heavy_ChaffVerb::cSystem_dNjRU3xi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DS6vahZU, HV_BINOP_DIVIDE, 1, m, &cBinop_DS6vahZU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0HicDVWX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_1KvHx0zP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1KvHx0zP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4Jr7TZZR, m);
}

void Heavy_ChaffVerb::cMsg_PjSVFuwC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HfJHhk9u_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HfJHhk9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_3wr1fDK2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CoDZvMac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_8W9GCEti, m);
}

void Heavy_ChaffVerb::cBinop_jRXx53AA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_cC90eXYr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cC90eXYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DS6vahZU, HV_BINOP_DIVIDE, 0, m, &cBinop_DS6vahZU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DS6vahZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PjSVFuwC_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_pGb4paBo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7E64BD01: { // "seed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_r9iMewng, 0, m, &cSlice_r9iMewng_sendMessage);
      break;
    }
    default: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_uZGlEot1, 0, m, &cRandom_uZGlEot1_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_tceu9uQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_6s0ELgrF_sendMessage);
}

void Heavy_ChaffVerb::cUnop_6s0ELgrF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 50.0f, 0, m, &cBinop_7ToFA9Mp_sendMessage);
}

void Heavy_ChaffVerb::cRandom_uZGlEot1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_tceu9uQz_sendMessage);
}

void Heavy_ChaffVerb::cSlice_r9iMewng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_uZGlEot1, 1, m, &cRandom_uZGlEot1_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSwitchcase_sxE1rM2m_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_Flyb9Ncd_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_Flyb9Ncd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lngTOVZj_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_8r6cMHUH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8r6cMHUH, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8r6cMHUH, 0, m, &cDelay_8r6cMHUH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SAYtVUv1, 0, m, &cVar_SAYtVUv1_sendMessage);
}

void Heavy_ChaffVerb::cCast_lngTOVZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Flyb9Ncd_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8r6cMHUH, 0, m, &cDelay_8r6cMHUH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SAYtVUv1, 0, m, &cVar_SAYtVUv1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2N9bKptX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cRHHUhtZ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_cRHHUhtZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_mftULQbM_sendMessage);
}

void Heavy_ChaffVerb::cVar_lgWaErcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JHNAIITP, HV_BINOP_MULTIPLY, 0, m, &cBinop_JHNAIITP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Flyb9Ncd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8r6cMHUH, 0, m, &cDelay_8r6cMHUH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Ti39A92l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8r6cMHUH, 2, m, &cDelay_8r6cMHUH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mftULQbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JHNAIITP, HV_BINOP_MULTIPLY, 1, m, &cBinop_JHNAIITP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JHNAIITP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_Ti39A92l_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_kbp9ZY19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MeXgiuul, HV_BINOP_SUBTRACT, 0, m, &cBinop_MeXgiuul_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9BEkpWKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SMlWEC5w_sendMessage);
}

void Heavy_ChaffVerb::cSystem_SMlWEC5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_bwVSIcAD_sendMessage);
}

void Heavy_ChaffVerb::cVar_M4Mu8DTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6xvBmoHT_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_stpocBAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_stpocBAN, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rmGIPMZo, 0, m, &cDelay_rmGIPMZo_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_voxtaPEX, 0, m, &sTabread_voxtaPEX_sendMessage);
}

void Heavy_ChaffVerb::cDelay_rmGIPMZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rmGIPMZo, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_voxtaPEX, 0, m, &sTabread_voxtaPEX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rmGIPMZo, 0, m, &cDelay_rmGIPMZo_sendMessage);
}

void Heavy_ChaffVerb::sTabread_voxtaPEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_IFNxLmbS, HV_BINOP_SUBTRACT, 0, m, &cBinop_IFNxLmbS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_rxQJoDlQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TeFKl0Gr, HV_BINOP_MAX, 0, m, &cBinop_TeFKl0Gr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bwVSIcAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rxQJoDlQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_rxQJoDlQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MeXgiuul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9bOC12DW_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_voxtaPEX, 0, m, &sTabread_voxtaPEX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JKN7z1h0_sendMessage);
}

void Heavy_ChaffVerb::cSystem_clnAoCPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IFNxLmbS, HV_BINOP_SUBTRACT, 1, m, &cBinop_IFNxLmbS_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rmGIPMZo, 2, m, &cDelay_rmGIPMZo_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6xvBmoHT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_clnAoCPM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9bOC12DW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_stpocBAN, 0, m, &cDelay_stpocBAN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rmGIPMZo, 0, m, &cDelay_rmGIPMZo_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8F8fddys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_TeFKl0Gr, HV_BINOP_MAX, 1, m, &cBinop_TeFKl0Gr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TeFKl0Gr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MeXgiuul, HV_BINOP_SUBTRACT, 1, m, &cBinop_MeXgiuul_sendMessage);
}

void Heavy_ChaffVerb::cCast_JKN7z1h0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_stpocBAN, 0, m, &cDelay_stpocBAN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3WVb3j2c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_stpocBAN, 2, m, &cDelay_stpocBAN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IFNxLmbS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_3WVb3j2c_sendMessage);
}

void Heavy_ChaffVerb::cCast_Ie5gG5xC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M4Mu8DTZ, 0, m, &cVar_M4Mu8DTZ_sendMessage);
  cMsg_9BEkpWKN_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_kbp9ZY19, 0, m, &cTabhead_kbp9ZY19_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_449Ew2Ts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_31J7JUqT, HV_BINOP_SUBTRACT, 0, m, &cBinop_31J7JUqT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hgNI4mgB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_egMGhvAM_sendMessage);
}

void Heavy_ChaffVerb::cSystem_egMGhvAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_0p1CUark_sendMessage);
}

void Heavy_ChaffVerb::cVar_3BuTpOJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FMHIb7tE_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_qPaX44RG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qPaX44RG, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WBCGgNnK, 0, m, &cDelay_WBCGgNnK_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ctLULMbY, 0, m, &sTabread_ctLULMbY_sendMessage);
}

void Heavy_ChaffVerb::cDelay_WBCGgNnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WBCGgNnK, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ctLULMbY, 0, m, &sTabread_ctLULMbY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WBCGgNnK, 0, m, &cDelay_WBCGgNnK_sendMessage);
}

void Heavy_ChaffVerb::sTabread_ctLULMbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_MPDzeUCk, HV_BINOP_SUBTRACT, 0, m, &cBinop_MPDzeUCk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_TGePZbnt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WBLiUy5d, HV_BINOP_MAX, 0, m, &cBinop_WBLiUy5d_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0p1CUark_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TGePZbnt, HV_BINOP_MULTIPLY, 0, m, &cBinop_TGePZbnt_sendMessage);
}

void Heavy_ChaffVerb::cBinop_31J7JUqT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UydlxfED_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ctLULMbY, 0, m, &sTabread_ctLULMbY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kwAYs1ZJ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_3PbBtz7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MPDzeUCk, HV_BINOP_SUBTRACT, 1, m, &cBinop_MPDzeUCk_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WBCGgNnK, 2, m, &cDelay_WBCGgNnK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FMHIb7tE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3PbBtz7x_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UydlxfED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_qPaX44RG, 0, m, &cDelay_qPaX44RG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WBCGgNnK, 0, m, &cDelay_WBCGgNnK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2aUzXwwI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_WBLiUy5d, HV_BINOP_MAX, 1, m, &cBinop_WBLiUy5d_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WBLiUy5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_31J7JUqT, HV_BINOP_SUBTRACT, 1, m, &cBinop_31J7JUqT_sendMessage);
}

void Heavy_ChaffVerb::cCast_kwAYs1ZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qPaX44RG, 0, m, &cDelay_qPaX44RG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_orGBXCYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qPaX44RG, 2, m, &cDelay_qPaX44RG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MPDzeUCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_orGBXCYe_sendMessage);
}

void Heavy_ChaffVerb::cCast_JjUF09gt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3BuTpOJv, 0, m, &cVar_3BuTpOJv_sendMessage);
  cMsg_hgNI4mgB_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_449Ew2Ts, 0, m, &cTabhead_449Ew2Ts_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_PiwKv6yL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zdIRmVsu, HV_BINOP_SUBTRACT, 0, m, &cBinop_zdIRmVsu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_bdJ36u3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UKILptXO_sendMessage);
}

void Heavy_ChaffVerb::cSystem_UKILptXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Lc5xn87v_sendMessage);
}

void Heavy_ChaffVerb::cVar_z56r03Rq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rDXmEUUl_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_b7Bh6mYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_b7Bh6mYR, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_35UhAPtL, 0, m, &cDelay_35UhAPtL_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Bwo6FKNV, 0, m, &sTabread_Bwo6FKNV_sendMessage);
}

void Heavy_ChaffVerb::cDelay_35UhAPtL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_35UhAPtL, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Bwo6FKNV, 0, m, &sTabread_Bwo6FKNV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_35UhAPtL, 0, m, &cDelay_35UhAPtL_sendMessage);
}

void Heavy_ChaffVerb::sTabread_Bwo6FKNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_bCxm5Inx, HV_BINOP_SUBTRACT, 0, m, &cBinop_bCxm5Inx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_E3xqO6mL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ULMJGXE7, HV_BINOP_MAX, 0, m, &cBinop_ULMJGXE7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Lc5xn87v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E3xqO6mL, HV_BINOP_MULTIPLY, 0, m, &cBinop_E3xqO6mL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zdIRmVsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qGqHczke_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Bwo6FKNV, 0, m, &sTabread_Bwo6FKNV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RtX3hbrJ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_vVCur4ZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bCxm5Inx, HV_BINOP_SUBTRACT, 1, m, &cBinop_bCxm5Inx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_35UhAPtL, 2, m, &cDelay_35UhAPtL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rDXmEUUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vVCur4ZL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qGqHczke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_b7Bh6mYR, 0, m, &cDelay_b7Bh6mYR_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_35UhAPtL, 0, m, &cDelay_35UhAPtL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xErKRWcc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_ULMJGXE7, HV_BINOP_MAX, 1, m, &cBinop_ULMJGXE7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ULMJGXE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zdIRmVsu, HV_BINOP_SUBTRACT, 1, m, &cBinop_zdIRmVsu_sendMessage);
}

void Heavy_ChaffVerb::cCast_RtX3hbrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_b7Bh6mYR, 0, m, &cDelay_b7Bh6mYR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1wWMEZpc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_b7Bh6mYR, 2, m, &cDelay_b7Bh6mYR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bCxm5Inx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1wWMEZpc_sendMessage);
}

void Heavy_ChaffVerb::cCast_WsHUdLiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_z56r03Rq, 0, m, &cVar_z56r03Rq_sendMessage);
  cMsg_bdJ36u3R_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_PiwKv6yL, 0, m, &cTabhead_PiwKv6yL_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_8ABEGJvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f83e0GhO, HV_BINOP_SUBTRACT, 0, m, &cBinop_f83e0GhO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LZmz9gd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_88uUyjpx_sendMessage);
}

void Heavy_ChaffVerb::cSystem_88uUyjpx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Bk1JzQZQ_sendMessage);
}

void Heavy_ChaffVerb::cVar_nFVe3oHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I1IqZwl0_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_ddw3la3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ddw3la3Q, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kfXQmJwV, 0, m, &cDelay_kfXQmJwV_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_we43Zb4Y, 0, m, &sTabread_we43Zb4Y_sendMessage);
}

void Heavy_ChaffVerb::cDelay_kfXQmJwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kfXQmJwV, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_we43Zb4Y, 0, m, &sTabread_we43Zb4Y_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kfXQmJwV, 0, m, &cDelay_kfXQmJwV_sendMessage);
}

void Heavy_ChaffVerb::sTabread_we43Zb4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_ATfWsBAh, HV_BINOP_SUBTRACT, 0, m, &cBinop_ATfWsBAh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_BwgFai7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6sNtGTU2, HV_BINOP_MAX, 0, m, &cBinop_6sNtGTU2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Bk1JzQZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BwgFai7f, HV_BINOP_MULTIPLY, 0, m, &cBinop_BwgFai7f_sendMessage);
}

void Heavy_ChaffVerb::cBinop_f83e0GhO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qQ7hLotV_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_we43Zb4Y, 0, m, &sTabread_we43Zb4Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lLeLe6hH_sendMessage);
}

void Heavy_ChaffVerb::cSystem_OrMClQrr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ATfWsBAh, HV_BINOP_SUBTRACT, 1, m, &cBinop_ATfWsBAh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kfXQmJwV, 2, m, &cDelay_kfXQmJwV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_I1IqZwl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_OrMClQrr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qQ7hLotV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ddw3la3Q, 0, m, &cDelay_ddw3la3Q_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kfXQmJwV, 0, m, &cDelay_kfXQmJwV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Bl8AX1jO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_6sNtGTU2, HV_BINOP_MAX, 1, m, &cBinop_6sNtGTU2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6sNtGTU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f83e0GhO, HV_BINOP_SUBTRACT, 1, m, &cBinop_f83e0GhO_sendMessage);
}

void Heavy_ChaffVerb::cCast_lLeLe6hH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ddw3la3Q, 0, m, &cDelay_ddw3la3Q_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XCOMqxAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ddw3la3Q, 2, m, &cDelay_ddw3la3Q_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ATfWsBAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_XCOMqxAn_sendMessage);
}

void Heavy_ChaffVerb::cCast_I6Ua28yM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nFVe3oHL, 0, m, &cVar_nFVe3oHL_sendMessage);
  cMsg_LZmz9gd9_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_8ABEGJvL, 0, m, &cTabhead_8ABEGJvL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JAcQcf3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XNHRHWER_sendMessage);
}

void Heavy_ChaffVerb::cSystem_XNHRHWER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_zIwlgfdK_sendMessage);
}

void Heavy_ChaffVerb::cDelay_LS97W8By_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LS97W8By, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xBxbU6sz, 0, m, &cDelay_xBxbU6sz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LS97W8By, 0, m, &cDelay_LS97W8By_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_eF3lDk9I, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_xBxbU6sz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xBxbU6sz, m);
  cMsg_WWvs84eZ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_gXHTUOXL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_xLur4c50_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_XczsfHf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WyQoHKYp_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_w1CcRl7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MHJs6FGB_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LS97W8By, 2, m, &cDelay_LS97W8By_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FS3pyTE8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_WyQoHKYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_w1CcRl7x, 0, m, &hTable_w1CcRl7x_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zIwlgfdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 58.6435f, 0, m, &cBinop_XczsfHf1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_WWvs84eZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_w1CcRl7x, 0, m, &hTable_w1CcRl7x_sendMessage);
}

void Heavy_ChaffVerb::cCast_FS3pyTE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_LS97W8By, 0, m, &cDelay_LS97W8By_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MHJs6FGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_xBxbU6sz, 2, m, &cDelay_xBxbU6sz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xLur4c50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_eF3lDk9I, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_l68FpaAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kX6fSsaZ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_kX6fSsaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qEbRRNpJ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_bUPOxNzN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bUPOxNzN, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3SEzDdL1, 0, m, &cDelay_3SEzDdL1_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bUPOxNzN, 0, m, &cDelay_bUPOxNzN_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_H2DgVUXc, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_3SEzDdL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3SEzDdL1, m);
  cMsg_ZifzqUEY_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_gmYEMO0N_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_eKjNeijP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_8AGgZJej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zbWhWEGW_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_HKOIdPB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ypnc8pum_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bUPOxNzN, 2, m, &cDelay_bUPOxNzN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OlXATw7h_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zbWhWEGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_HKOIdPB2, 0, m, &hTable_HKOIdPB2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qEbRRNpJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 69.4325f, 0, m, &cBinop_8AGgZJej_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZifzqUEY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_HKOIdPB2, 0, m, &hTable_HKOIdPB2_sendMessage);
}

void Heavy_ChaffVerb::cCast_OlXATw7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bUPOxNzN, 0, m, &cDelay_bUPOxNzN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ypnc8pum_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_3SEzDdL1, 2, m, &cDelay_3SEzDdL1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_eKjNeijP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_H2DgVUXc, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_YryOYtpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Z6wU8uvj_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Z6wU8uvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_A9o9Sv8J_sendMessage);
}

void Heavy_ChaffVerb::cDelay_3DKaYwww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3DKaYwww, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kH02h8nS, 0, m, &cDelay_kH02h8nS_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3DKaYwww, 0, m, &cDelay_3DKaYwww_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_c0Yu9ky1, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_kH02h8nS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kH02h8nS, m);
  cMsg_tHK1VrCK_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_oO8dt0Uj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_1xUCtGbu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_9b1VVm4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dym2eUzC_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_weaGl6kg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uCzqiSiz_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3DKaYwww, 2, m, &cDelay_3DKaYwww_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pYLfwcjp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dym2eUzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_weaGl6kg, 0, m, &hTable_weaGl6kg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_A9o9Sv8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 74.5234f, 0, m, &cBinop_9b1VVm4Z_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tHK1VrCK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_weaGl6kg, 0, m, &hTable_weaGl6kg_sendMessage);
}

void Heavy_ChaffVerb::cCast_pYLfwcjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3DKaYwww, 0, m, &cDelay_3DKaYwww_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uCzqiSiz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_kH02h8nS, 2, m, &cDelay_kH02h8nS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1xUCtGbu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_c0Yu9ky1, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_voTGrck6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JlqppTiU_sendMessage);
}

void Heavy_ChaffVerb::cSystem_JlqppTiU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_2mVSK3SS_sendMessage);
}

void Heavy_ChaffVerb::cDelay_iurxkYN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_iurxkYN2, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qZAwpew2, 0, m, &cDelay_qZAwpew2_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iurxkYN2, 0, m, &cDelay_iurxkYN2_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_GzhOi7Ay, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_qZAwpew2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qZAwpew2, m);
  cMsg_MLGjHUsv_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_5pvr8pMS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_kZpTeJNA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_VX07xZUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9B9MMmy0_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_KwXYxzhr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8s21GGbi_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iurxkYN2, 2, m, &cDelay_iurxkYN2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tUMV1BZ8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9B9MMmy0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_KwXYxzhr, 0, m, &hTable_KwXYxzhr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2mVSK3SS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 86.1244f, 0, m, &cBinop_VX07xZUT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MLGjHUsv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_KwXYxzhr, 0, m, &hTable_KwXYxzhr_sendMessage);
}

void Heavy_ChaffVerb::cCast_tUMV1BZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_iurxkYN2, 0, m, &cDelay_iurxkYN2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8s21GGbi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_qZAwpew2, 2, m, &cDelay_qZAwpew2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kZpTeJNA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_GzhOi7Ay, 1, m, NULL);
}

void Heavy_ChaffVerb::cPack_aAwZ2G0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_sKtHIecZ, 0, m, NULL);
}

void Heavy_ChaffVerb::cPack_1lRklqTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_KzGWmAVR, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_CGDehXv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_VeU9oGJy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VeU9oGJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 200.0f, 0, m, &cBinop_zRaqiAKp_sendMessage);
}

void Heavy_ChaffVerb::cVar_Z3WHAwJW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qQRdFZi6, HV_BINOP_MULTIPLY, 0, m, &cBinop_qQRdFZi6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nfOpOV86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QKIrvqxE_sendMessage);
}

void Heavy_ChaffVerb::cSystem_QKIrvqxE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tNQp1NU3_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_qQRdFZi6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_x8bXgXQR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5nqLqB7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qQRdFZi6, HV_BINOP_MULTIPLY, 1, m, &cBinop_qQRdFZi6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tNQp1NU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_5nqLqB7q_sendMessage);
}

void Heavy_ChaffVerb::cBinop_x8bXgXQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_6qBe06N5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6qBe06N5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_eNv4FVlL_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_fT3u6SEp, m);
}

void Heavy_ChaffVerb::cBinop_eNv4FVlL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_qpEtdoNK, m);
}

void Heavy_ChaffVerb::cVar_OkpriRfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.125f, 0, m, &cBinop_TsMSpxl0_sendMessage);
}

void Heavy_ChaffVerb::cVar_31QHT4BV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_CGDehXv9_sendMessage);
}

void Heavy_ChaffVerb::cVar_XsoDXfYE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN_EQL, 1.0f, 0, m, &cBinop_1pbcJvix_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_03zvhVOW, 0, m, &cIf_03zvhVOW_sendMessage);
}

void Heavy_ChaffVerb::cVar_C8qvgVEY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_l8G1Yp6S_sendMessage);
}

void Heavy_ChaffVerb::cIf_03zvhVOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_CJS22Otw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_7eIZrsrH, 0, m, &cVar_7eIZrsrH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_1pbcJvix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_03zvhVOW, 1, m, &cIf_03zvhVOW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_l8G1Yp6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_AX1IYJBw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_AX1IYJBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e4QjC6qu, 0, m, &cVar_e4QjC6qu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5ilJ1Xjx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cf85wKly_sendMessage);
}

void Heavy_ChaffVerb::cSystem_cf85wKly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Hdt6gRPI_sendMessage);
}

void Heavy_ChaffVerb::cDelay_vWTwwCWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vWTwwCWW, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xigpHyBw, 0, m, &cDelay_xigpHyBw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vWTwwCWW, 0, m, &cDelay_vWTwwCWW_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_xvcTTCIt, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_xigpHyBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xigpHyBw, m);
  cMsg_KFfWhJKA_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_sHokb4FL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_qxRbzbW6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_oYIN6zcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c50bT9WM_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_Mgmx2cg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ipxA60xu_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vWTwwCWW, 2, m, &cDelay_vWTwwCWW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rSXUktVb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_c50bT9WM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Mgmx2cg1, 0, m, &hTable_Mgmx2cg1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Hdt6gRPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 43.5337f, 0, m, &cBinop_oYIN6zcP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KFfWhJKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Mgmx2cg1, 0, m, &hTable_Mgmx2cg1_sendMessage);
}

void Heavy_ChaffVerb::cCast_rSXUktVb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vWTwwCWW, 0, m, &cDelay_vWTwwCWW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ipxA60xu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_xigpHyBw, 2, m, &cDelay_xigpHyBw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qxRbzbW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_xvcTTCIt, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_YuSMcQsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e21mF30h, HV_BINOP_SUBTRACT, 0, m, &cBinop_e21mF30h_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IBf6TNbc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CjSwxC9c_sendMessage);
}

void Heavy_ChaffVerb::cSystem_CjSwxC9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_aOHsof7v_sendMessage);
}

void Heavy_ChaffVerb::cVar_B1Hsykvz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TX6DfCK1_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_9F8I61nS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9F8I61nS, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XuwV73cU, 0, m, &cDelay_XuwV73cU_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_yTfcWTOF, 0, m, &sTabread_yTfcWTOF_sendMessage);
}

void Heavy_ChaffVerb::cDelay_XuwV73cU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XuwV73cU, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_yTfcWTOF, 0, m, &sTabread_yTfcWTOF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XuwV73cU, 0, m, &cDelay_XuwV73cU_sendMessage);
}

void Heavy_ChaffVerb::sTabread_yTfcWTOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_lVsWuqm8, HV_BINOP_SUBTRACT, 0, m, &cBinop_lVsWuqm8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_4aSSszXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9iXO750v, HV_BINOP_MAX, 0, m, &cBinop_9iXO750v_sendMessage);
}

void Heavy_ChaffVerb::cBinop_aOHsof7v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4aSSszXe, HV_BINOP_MULTIPLY, 0, m, &cBinop_4aSSszXe_sendMessage);
}

void Heavy_ChaffVerb::cBinop_e21mF30h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8rQXZFTg_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_yTfcWTOF, 0, m, &sTabread_yTfcWTOF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vR4lkQas_sendMessage);
}

void Heavy_ChaffVerb::cSystem_tmTj6hr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lVsWuqm8, HV_BINOP_SUBTRACT, 1, m, &cBinop_lVsWuqm8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XuwV73cU, 2, m, &cDelay_XuwV73cU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TX6DfCK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tmTj6hr5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8rQXZFTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9F8I61nS, 0, m, &cDelay_9F8I61nS_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XuwV73cU, 0, m, &cDelay_XuwV73cU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NPlKGRQN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_9iXO750v, HV_BINOP_MAX, 1, m, &cBinop_9iXO750v_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9iXO750v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e21mF30h, HV_BINOP_SUBTRACT, 1, m, &cBinop_e21mF30h_sendMessage);
}

void Heavy_ChaffVerb::cCast_vR4lkQas_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9F8I61nS, 0, m, &cDelay_9F8I61nS_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VCzwGXEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9F8I61nS, 2, m, &cDelay_9F8I61nS_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lVsWuqm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_VCzwGXEp_sendMessage);
}

void Heavy_ChaffVerb::cCast_fotr4QNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_B1Hsykvz, 0, m, &cVar_B1Hsykvz_sendMessage);
  cMsg_IBf6TNbc_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_YuSMcQsu, 0, m, &cTabhead_YuSMcQsu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LM0t4SnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZCkhd4lK_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ZCkhd4lK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_U00u69E3_sendMessage);
}

void Heavy_ChaffVerb::cDelay_o3YeXRwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_o3YeXRwc, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3CW05JD6, 0, m, &cDelay_3CW05JD6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_o3YeXRwc, 0, m, &cDelay_o3YeXRwc_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_8WxOzIRJ, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_3CW05JD6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3CW05JD6, m);
  cMsg_a61OGBAd_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_kGKuiUyq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_U2Myb4ch_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_1pWjJM4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NxAdH1ab_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_ZeJYG2Hi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mTBZhiZs_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_o3YeXRwc, 2, m, &cDelay_o3YeXRwc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ExVo8BzL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NxAdH1ab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ZeJYG2Hi, 0, m, &hTable_ZeJYG2Hi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_U00u69E3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 25.796f, 0, m, &cBinop_1pWjJM4K_sendMessage);
}

void Heavy_ChaffVerb::cMsg_a61OGBAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ZeJYG2Hi, 0, m, &hTable_ZeJYG2Hi_sendMessage);
}

void Heavy_ChaffVerb::cCast_ExVo8BzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_o3YeXRwc, 0, m, &cDelay_o3YeXRwc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mTBZhiZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_3CW05JD6, 2, m, &cDelay_3CW05JD6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_U2Myb4ch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_8WxOzIRJ, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_op7odMY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_72tigk5C, HV_BINOP_SUBTRACT, 0, m, &cBinop_72tigk5C_sendMessage);
}

void Heavy_ChaffVerb::cMsg_81oqzR5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GqMUpxje_sendMessage);
}

void Heavy_ChaffVerb::cSystem_GqMUpxje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_poZnIrzN_sendMessage);
}

void Heavy_ChaffVerb::cVar_ILBjhUwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IOd40Ds0_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_lhURGSVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lhURGSVJ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_j87KPjuE, 0, m, &cDelay_j87KPjuE_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gc69BEPk, 0, m, &sTabread_gc69BEPk_sendMessage);
}

void Heavy_ChaffVerb::cDelay_j87KPjuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_j87KPjuE, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gc69BEPk, 0, m, &sTabread_gc69BEPk_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_j87KPjuE, 0, m, &cDelay_j87KPjuE_sendMessage);
}

void Heavy_ChaffVerb::sTabread_gc69BEPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_ZdgpdeqX, HV_BINOP_SUBTRACT, 0, m, &cBinop_ZdgpdeqX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_g8bguxDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f6kTTIr4, HV_BINOP_MAX, 0, m, &cBinop_f6kTTIr4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_poZnIrzN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g8bguxDn, HV_BINOP_MULTIPLY, 0, m, &cBinop_g8bguxDn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_72tigk5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xkn9T92z_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gc69BEPk, 0, m, &sTabread_gc69BEPk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0NjqL9KC_sendMessage);
}

void Heavy_ChaffVerb::cSystem_2QHCzxC5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZdgpdeqX, HV_BINOP_SUBTRACT, 1, m, &cBinop_ZdgpdeqX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_j87KPjuE, 2, m, &cDelay_j87KPjuE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IOd40Ds0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2QHCzxC5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Xkn9T92z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lhURGSVJ, 0, m, &cDelay_lhURGSVJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_j87KPjuE, 0, m, &cDelay_j87KPjuE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GhODPYu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_f6kTTIr4, HV_BINOP_MAX, 1, m, &cBinop_f6kTTIr4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_f6kTTIr4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_72tigk5C, HV_BINOP_SUBTRACT, 1, m, &cBinop_72tigk5C_sendMessage);
}

void Heavy_ChaffVerb::cCast_0NjqL9KC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lhURGSVJ, 0, m, &cDelay_lhURGSVJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TBwuFjj9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lhURGSVJ, 2, m, &cDelay_lhURGSVJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZdgpdeqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_TBwuFjj9_sendMessage);
}

void Heavy_ChaffVerb::cCast_91CDBl1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ILBjhUwg, 0, m, &cVar_ILBjhUwg_sendMessage);
  cMsg_81oqzR5O_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_op7odMY5, 0, m, &cTabhead_op7odMY5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_b1F0mr6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_94s6GKJp_sendMessage);
}

void Heavy_ChaffVerb::cSystem_94s6GKJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_2xl5tLlM_sendMessage);
}

void Heavy_ChaffVerb::cDelay_VMLbtWRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VMLbtWRb, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IYdRUWU6, 0, m, &cDelay_IYdRUWU6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VMLbtWRb, 0, m, &cDelay_VMLbtWRb_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_f1b2SbLs, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_IYdRUWU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IYdRUWU6, m);
  cMsg_dXoRYwE2_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_yiG0rb2t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_BMh7DZpv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_ztxmuUze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L0RyNUHz_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_lYyPC86n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UfZPeJkb_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VMLbtWRb, 2, m, &cDelay_VMLbtWRb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jRfEQ4D4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_L0RyNUHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_lYyPC86n, 0, m, &hTable_lYyPC86n_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2xl5tLlM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 19.392f, 0, m, &cBinop_ztxmuUze_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dXoRYwE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_lYyPC86n, 0, m, &hTable_lYyPC86n_sendMessage);
}

void Heavy_ChaffVerb::cCast_jRfEQ4D4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VMLbtWRb, 0, m, &cDelay_VMLbtWRb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UfZPeJkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_IYdRUWU6, 2, m, &cDelay_IYdRUWU6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BMh7DZpv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_f1b2SbLs, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_yXkPKi2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oUVYyPCD, HV_BINOP_SUBTRACT, 0, m, &cBinop_oUVYyPCD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VaCjELye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jVfg1tG9_sendMessage);
}

void Heavy_ChaffVerb::cSystem_jVfg1tG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_T5iYSDbs_sendMessage);
}

void Heavy_ChaffVerb::cVar_A7pJbzQa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XglpDhQt_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_xEZCqDTI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xEZCqDTI, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CoMl2W8a, 0, m, &cDelay_CoMl2W8a_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_jd8v8eTI, 0, m, &sTabread_jd8v8eTI_sendMessage);
}

void Heavy_ChaffVerb::cDelay_CoMl2W8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CoMl2W8a, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_jd8v8eTI, 0, m, &sTabread_jd8v8eTI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CoMl2W8a, 0, m, &cDelay_CoMl2W8a_sendMessage);
}

void Heavy_ChaffVerb::sTabread_jd8v8eTI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_djnk99Lw, HV_BINOP_SUBTRACT, 0, m, &cBinop_djnk99Lw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_eFiSLxHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ARR0OOu3, HV_BINOP_MAX, 0, m, &cBinop_ARR0OOu3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_T5iYSDbs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eFiSLxHm, HV_BINOP_MULTIPLY, 0, m, &cBinop_eFiSLxHm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_oUVYyPCD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EHPorNju_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_jd8v8eTI, 0, m, &sTabread_jd8v8eTI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SCU9UGbd_sendMessage);
}

void Heavy_ChaffVerb::cSystem_8DkIZidU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_djnk99Lw, HV_BINOP_SUBTRACT, 1, m, &cBinop_djnk99Lw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CoMl2W8a, 2, m, &cDelay_CoMl2W8a_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XglpDhQt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8DkIZidU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_EHPorNju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xEZCqDTI, 0, m, &cDelay_xEZCqDTI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CoMl2W8a, 0, m, &cDelay_CoMl2W8a_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gB2gco1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_ARR0OOu3, HV_BINOP_MAX, 1, m, &cBinop_ARR0OOu3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ARR0OOu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oUVYyPCD, HV_BINOP_SUBTRACT, 1, m, &cBinop_oUVYyPCD_sendMessage);
}

void Heavy_ChaffVerb::cCast_SCU9UGbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xEZCqDTI, 0, m, &cDelay_xEZCqDTI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Hk4onTfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xEZCqDTI, 2, m, &cDelay_xEZCqDTI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_djnk99Lw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Hk4onTfs_sendMessage);
}

void Heavy_ChaffVerb::cCast_i87NJzh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_A7pJbzQa, 0, m, &cVar_A7pJbzQa_sendMessage);
  cMsg_VaCjELye_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_yXkPKi2m, 0, m, &cTabhead_yXkPKi2m_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SMLWZ9R2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2iXrSHEG_sendMessage);
}

void Heavy_ChaffVerb::cSystem_2iXrSHEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_iyCFQCi7_sendMessage);
}

void Heavy_ChaffVerb::cDelay_D6m5cNat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_D6m5cNat, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BLmR09sr, 0, m, &cDelay_BLmR09sr_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_D6m5cNat, 0, m, &cDelay_D6m5cNat_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_KVZuN0wL, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_BLmR09sr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BLmR09sr, m);
  cMsg_dniOm1QV_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_yKs1oD8X_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_rjQFT8Xv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_U36FebgB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sz1ANlmH_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_3tlLcWtp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N5ta76aO_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_D6m5cNat, 2, m, &cDelay_D6m5cNat_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HCseirPf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sz1ANlmH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_3tlLcWtp, 0, m, &hTable_3tlLcWtp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_iyCFQCi7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 16.364f, 0, m, &cBinop_U36FebgB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dniOm1QV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_3tlLcWtp, 0, m, &hTable_3tlLcWtp_sendMessage);
}

void Heavy_ChaffVerb::cCast_HCseirPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_D6m5cNat, 0, m, &cDelay_D6m5cNat_sendMessage);
}

void Heavy_ChaffVerb::cMsg_N5ta76aO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_BLmR09sr, 2, m, &cDelay_BLmR09sr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rjQFT8Xv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_KVZuN0wL, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_hXO3fcjJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IXZH2jZ7, HV_BINOP_SUBTRACT, 0, m, &cBinop_IXZH2jZ7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6Niutkem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sAA0mA2g_sendMessage);
}

void Heavy_ChaffVerb::cSystem_sAA0mA2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_nak7MDfD_sendMessage);
}

void Heavy_ChaffVerb::cVar_AaIFL8LU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tkxCOREo_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_q40AgYgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_q40AgYgm, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_79HrYtyk, 0, m, &cDelay_79HrYtyk_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_afV6PBIq, 0, m, &sTabread_afV6PBIq_sendMessage);
}

void Heavy_ChaffVerb::cDelay_79HrYtyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_79HrYtyk, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_afV6PBIq, 0, m, &sTabread_afV6PBIq_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_79HrYtyk, 0, m, &cDelay_79HrYtyk_sendMessage);
}

void Heavy_ChaffVerb::sTabread_afV6PBIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_SgAts0sa, HV_BINOP_SUBTRACT, 0, m, &cBinop_SgAts0sa_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_8AKgWEzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i8FMYRvg, HV_BINOP_MAX, 0, m, &cBinop_i8FMYRvg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nak7MDfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8AKgWEzW, HV_BINOP_MULTIPLY, 0, m, &cBinop_8AKgWEzW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IXZH2jZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QvMuZID3_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_afV6PBIq, 0, m, &sTabread_afV6PBIq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tIytsxMw_sendMessage);
}

void Heavy_ChaffVerb::cSystem_0eUuWaAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SgAts0sa, HV_BINOP_SUBTRACT, 1, m, &cBinop_SgAts0sa_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_79HrYtyk, 2, m, &cDelay_79HrYtyk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tkxCOREo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0eUuWaAN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QvMuZID3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_q40AgYgm, 0, m, &cDelay_q40AgYgm_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_79HrYtyk, 0, m, &cDelay_79HrYtyk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_bOiEcMS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_i8FMYRvg, HV_BINOP_MAX, 1, m, &cBinop_i8FMYRvg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_i8FMYRvg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IXZH2jZ7, HV_BINOP_SUBTRACT, 1, m, &cBinop_IXZH2jZ7_sendMessage);
}

void Heavy_ChaffVerb::cCast_tIytsxMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_q40AgYgm, 0, m, &cDelay_q40AgYgm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fmYxIzOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_q40AgYgm, 2, m, &cDelay_q40AgYgm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SgAts0sa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_fmYxIzOs_sendMessage);
}

void Heavy_ChaffVerb::cCast_Pxj3Z1bC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AaIFL8LU, 0, m, &cVar_AaIFL8LU_sendMessage);
  cMsg_6Niutkem_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_hXO3fcjJ, 0, m, &cTabhead_hXO3fcjJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yvhj2Hc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3MUdxLPs_sendMessage);
}

void Heavy_ChaffVerb::cSystem_3MUdxLPs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Nj4xJwSZ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_94epppIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_94epppIb, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5QTRdoNJ, 0, m, &cDelay_5QTRdoNJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_94epppIb, 0, m, &cDelay_94epppIb_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_eK1EKK8w, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_5QTRdoNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5QTRdoNJ, m);
  cMsg_QKEu9BQX_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_gg0LJu56_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_pAKvaZ7D_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_dPaTGo6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N6cJrrJf_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_dj8UlpVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UtqqXlQo_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_94epppIb, 2, m, &cDelay_94epppIb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WDicLq01_sendMessage);
}

void Heavy_ChaffVerb::cMsg_N6cJrrJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_dj8UlpVj, 0, m, &hTable_dj8UlpVj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Nj4xJwSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 4.2546f, 0, m, &cBinop_dPaTGo6A_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QKEu9BQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_dj8UlpVj, 0, m, &hTable_dj8UlpVj_sendMessage);
}

void Heavy_ChaffVerb::cCast_WDicLq01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_94epppIb, 0, m, &cDelay_94epppIb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UtqqXlQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_5QTRdoNJ, 2, m, &cDelay_5QTRdoNJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pAKvaZ7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_eK1EKK8w, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_K7RyFZAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aPmenPrI, HV_BINOP_SUBTRACT, 0, m, &cBinop_aPmenPrI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ER4DJTYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NbeMwgYB_sendMessage);
}

void Heavy_ChaffVerb::cSystem_NbeMwgYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qvRGAajQ_sendMessage);
}

void Heavy_ChaffVerb::cVar_GneM7Q8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pjAAxYa2_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_Ho8NhQA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ho8NhQA0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TWeYqmWR, 0, m, &cDelay_TWeYqmWR_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_l34qTGku, 0, m, &sTabread_l34qTGku_sendMessage);
}

void Heavy_ChaffVerb::cDelay_TWeYqmWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TWeYqmWR, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_l34qTGku, 0, m, &sTabread_l34qTGku_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TWeYqmWR, 0, m, &cDelay_TWeYqmWR_sendMessage);
}

void Heavy_ChaffVerb::sTabread_l34qTGku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_w78IkyqI, HV_BINOP_SUBTRACT, 0, m, &cBinop_w78IkyqI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_HgiWsFA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3uxHStoW, HV_BINOP_MAX, 0, m, &cBinop_3uxHStoW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qvRGAajQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HgiWsFA4, HV_BINOP_MULTIPLY, 0, m, &cBinop_HgiWsFA4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_aPmenPrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QFcUWkcP_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_l34qTGku, 0, m, &sTabread_l34qTGku_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9RUQctuF_sendMessage);
}

void Heavy_ChaffVerb::cSystem_7111Oyie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w78IkyqI, HV_BINOP_SUBTRACT, 1, m, &cBinop_w78IkyqI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TWeYqmWR, 2, m, &cDelay_TWeYqmWR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pjAAxYa2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7111Oyie_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QFcUWkcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ho8NhQA0, 0, m, &cDelay_Ho8NhQA0_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TWeYqmWR, 0, m, &cDelay_TWeYqmWR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ISUHIkm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_3uxHStoW, HV_BINOP_MAX, 1, m, &cBinop_3uxHStoW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3uxHStoW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aPmenPrI, HV_BINOP_SUBTRACT, 1, m, &cBinop_aPmenPrI_sendMessage);
}

void Heavy_ChaffVerb::cCast_9RUQctuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ho8NhQA0, 0, m, &cDelay_Ho8NhQA0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cVgfJjiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ho8NhQA0, 2, m, &cDelay_Ho8NhQA0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_w78IkyqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_cVgfJjiD_sendMessage);
}

void Heavy_ChaffVerb::cCast_J3mhazDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GneM7Q8c, 0, m, &cVar_GneM7Q8c_sendMessage);
  cMsg_ER4DJTYK_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_K7RyFZAL, 0, m, &cTabhead_K7RyFZAL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_c1cjDpJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nXnnm8PR_sendMessage);
}

void Heavy_ChaffVerb::cSystem_nXnnm8PR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_XsIvhF82_sendMessage);
}

void Heavy_ChaffVerb::cDelay_b3aiNhHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_b3aiNhHx, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BZ1wUFvM, 0, m, &cDelay_BZ1wUFvM_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_b3aiNhHx, 0, m, &cDelay_b3aiNhHx_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_jvWti33b, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_BZ1wUFvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BZ1wUFvM, m);
  cMsg_O5Es6BC8_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_ZKKDzFzf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_o476UZEt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_UyDhV6Ic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bep7PgpT_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_Hbzr2HCW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_haT1S1ja_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_b3aiNhHx, 2, m, &cDelay_b3aiNhHx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dt6lAlYS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_bep7PgpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Hbzr2HCW, 0, m, &hTable_Hbzr2HCW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XsIvhF82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 7.645f, 0, m, &cBinop_UyDhV6Ic_sendMessage);
}

void Heavy_ChaffVerb::cMsg_O5Es6BC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Hbzr2HCW, 0, m, &hTable_Hbzr2HCW_sendMessage);
}

void Heavy_ChaffVerb::cCast_dt6lAlYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_b3aiNhHx, 0, m, &cDelay_b3aiNhHx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_haT1S1ja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_BZ1wUFvM, 2, m, &cDelay_BZ1wUFvM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_o476UZEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_jvWti33b, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_1W4hWoEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RFsc2eLb, HV_BINOP_SUBTRACT, 0, m, &cBinop_RFsc2eLb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qvGX6TW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AjEpkMdX_sendMessage);
}

void Heavy_ChaffVerb::cSystem_AjEpkMdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_3dOebfph_sendMessage);
}

void Heavy_ChaffVerb::cVar_LLwKJ2DY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qckRpXKt_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_nOOb54TS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nOOb54TS, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OB5HtwN1, 0, m, &cDelay_OB5HtwN1_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_D5pz8pIq, 0, m, &sTabread_D5pz8pIq_sendMessage);
}

void Heavy_ChaffVerb::cDelay_OB5HtwN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OB5HtwN1, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_D5pz8pIq, 0, m, &sTabread_D5pz8pIq_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OB5HtwN1, 0, m, &cDelay_OB5HtwN1_sendMessage);
}

void Heavy_ChaffVerb::sTabread_D5pz8pIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Boq9Tgqi, HV_BINOP_SUBTRACT, 0, m, &cBinop_Boq9Tgqi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_qCtb4Zrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hz0tCc6n, HV_BINOP_MAX, 0, m, &cBinop_hz0tCc6n_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3dOebfph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qCtb4Zrt, HV_BINOP_MULTIPLY, 0, m, &cBinop_qCtb4Zrt_sendMessage);
}

void Heavy_ChaffVerb::cBinop_RFsc2eLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6WqIc9yS_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_D5pz8pIq, 0, m, &sTabread_D5pz8pIq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_plo76qyz_sendMessage);
}

void Heavy_ChaffVerb::cSystem_NT8QgS2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Boq9Tgqi, HV_BINOP_SUBTRACT, 1, m, &cBinop_Boq9Tgqi_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OB5HtwN1, 2, m, &cDelay_OB5HtwN1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qckRpXKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NT8QgS2m_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6WqIc9yS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_nOOb54TS, 0, m, &cDelay_nOOb54TS_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OB5HtwN1, 0, m, &cDelay_OB5HtwN1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_G37moVJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_hz0tCc6n, HV_BINOP_MAX, 1, m, &cBinop_hz0tCc6n_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hz0tCc6n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RFsc2eLb, HV_BINOP_SUBTRACT, 1, m, &cBinop_RFsc2eLb_sendMessage);
}

void Heavy_ChaffVerb::cCast_plo76qyz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nOOb54TS, 0, m, &cDelay_nOOb54TS_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HFpTnaro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nOOb54TS, 2, m, &cDelay_nOOb54TS_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Boq9Tgqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_HFpTnaro_sendMessage);
}

void Heavy_ChaffVerb::cCast_0sr8bLzk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LLwKJ2DY, 0, m, &cVar_LLwKJ2DY_sendMessage);
  cMsg_qvGX6TW2_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_1W4hWoEC, 0, m, &cTabhead_1W4hWoEC_sendMessage);
}

void Heavy_ChaffVerb::cVar_7eIZrsrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z3WHAwJW, 0, m, &cVar_Z3WHAwJW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0vY0zf7a, 0, m, &cVar_0vY0zf7a_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lMcABg8R, 0, m, &cVar_lMcABg8R_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Xn3p4Wkh, 0, m, &cVar_Xn3p4Wkh_sendMessage);
}

void Heavy_ChaffVerb::cVar_e4QjC6qu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.01f, 0, m, &cBinop_5L4J4gc2_sendMessage);
}

void Heavy_ChaffVerb::cPack_92Qv8Xf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_GQDNNPqU, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_0vY0zf7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6X9HX5j9, HV_BINOP_MULTIPLY, 0, m, &cBinop_6X9HX5j9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9bYeIqsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hOdRnXi4_sendMessage);
}

void Heavy_ChaffVerb::cSystem_hOdRnXi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cjEU0jaF_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_6X9HX5j9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_LGjKBMbH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ymRtxmk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6X9HX5j9, HV_BINOP_MULTIPLY, 1, m, &cBinop_6X9HX5j9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_cjEU0jaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ymRtxmk5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LGjKBMbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Qyi0torp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Qyi0torp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_dxZ8zMSM_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_KQ7zHV9X, m);
}

void Heavy_ChaffVerb::cBinop_dxZ8zMSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Cy93JAJg, m);
}

void Heavy_ChaffVerb::cVar_lMcABg8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2uQu6Hod, HV_BINOP_MULTIPLY, 0, m, &cBinop_2uQu6Hod_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GfY6y3OS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_65MvfgOL_sendMessage);
}

void Heavy_ChaffVerb::cSystem_65MvfgOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w0lE9DOW_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_2uQu6Hod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_au7CcuuU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Pth6FFBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2uQu6Hod, HV_BINOP_MULTIPLY, 1, m, &cBinop_2uQu6Hod_sendMessage);
}

void Heavy_ChaffVerb::cMsg_w0lE9DOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Pth6FFBK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_au7CcuuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_pndV2h7o_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pndV2h7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ZHIvFy7I_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_XOrJk30h, m);
}

void Heavy_ChaffVerb::cBinop_ZHIvFy7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_tiUtzi2h, m);
}

void Heavy_ChaffVerb::cVar_Xn3p4Wkh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L60BcJrr, HV_BINOP_MULTIPLY, 0, m, &cBinop_L60BcJrr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vGRfmo66_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZIgswIwu_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ZIgswIwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2DFOFtlD_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_L60BcJrr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_pkBXYrLR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3cTGmh13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L60BcJrr, HV_BINOP_MULTIPLY, 1, m, &cBinop_L60BcJrr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2DFOFtlD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3cTGmh13_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pkBXYrLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_f6PYrP4o_sendMessage);
}

void Heavy_ChaffVerb::cBinop_f6PYrP4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_xzfwI5cO_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_9SvE3brO, m);
}

void Heavy_ChaffVerb::cBinop_xzfwI5cO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_SlMUDRHI, m);
}

void Heavy_ChaffVerb::cBinop_zRaqiAKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_1lRklqTL, 0, m, &cPack_1lRklqTL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CJS22Otw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3000.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_7eIZrsrH, 0, m, &cVar_7eIZrsrH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5L4J4gc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_92Qv8Xf2, 0, m, &cPack_92Qv8Xf2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TsMSpxl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_aAwZ2G0R, 0, m, &cPack_aAwZ2G0R_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_GK6v2SzP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_LsmgY8cV_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_LsmgY8cV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kul8jChT_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_HNplLjy3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HNplLjy3, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HNplLjy3, 0, m, &cDelay_HNplLjy3_sendMessage);
  cSwitchcase_pGb4paBo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_kul8jChT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LsmgY8cV_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HNplLjy3, 0, m, &cDelay_HNplLjy3_sendMessage);
  cSwitchcase_pGb4paBo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cMsg_ubLYbhVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_f7UMRRfD_sendMessage);
}

void Heavy_ChaffVerb::cSystem_f7UMRRfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_q9i6AyN6_sendMessage);
}

void Heavy_ChaffVerb::cVar_f7BAu6ZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JKdNGvrL, HV_BINOP_MULTIPLY, 0, m, &cBinop_JKdNGvrL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LsmgY8cV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HNplLjy3, 0, m, &cDelay_HNplLjy3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_adYdiZ7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HNplLjy3, 2, m, &cDelay_HNplLjy3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_q9i6AyN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JKdNGvrL, HV_BINOP_MULTIPLY, 1, m, &cBinop_JKdNGvrL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JKdNGvrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_adYdiZ7w_sendMessage);
}

void Heavy_ChaffVerb::cVar_SAYtVUv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MOD_UNIPOLAR, 628.0f, 0, m, &cBinop_EZNsXLOq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 2.0f, 0, m, &cBinop_XKT11r1t_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_OkqMvj7h_sendMessage);
}

void Heavy_ChaffVerb::cVar_pF57YmUH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_SfyQIaZB_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_qT3VR0vL, 0, m, &cIf_qT3VR0vL_sendMessage);
}

void Heavy_ChaffVerb::cUnop_4wODEjVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5m8wKrhQ, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_5m8wKrhQ_sendMessage);
}

void Heavy_ChaffVerb::cUnop_66UMbNdt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5m8wKrhQ, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_5m8wKrhQ_sendMessage);
}

void Heavy_ChaffVerb::cIf_qT3VR0vL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_66UMbNdt_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_4wODEjVD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_SfyQIaZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qT3VR0vL, 1, m, &cIf_qT3VR0vL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LG0SZseJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6x9G4iF8_sendMessage);
}

void Heavy_ChaffVerb::cSystem_6x9G4iF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_oR9Gieiy_sendMessage);
}

void Heavy_ChaffVerb::cDelay_VkkHeLhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VkkHeLhM, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_EevCCH2a, 0, m, &cDelay_EevCCH2a_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VkkHeLhM, 0, m, &cDelay_VkkHeLhM_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LJaFtyr9, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_EevCCH2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EevCCH2a, m);
  cMsg_1CdEppHK_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_V3J65PL4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_VAgOopnF_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_uvLFGQ3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zLkwZeUK_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_mIAgTbtp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nRck9ON5_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VkkHeLhM, 2, m, &cDelay_VkkHeLhM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Xl2jtKNs_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zLkwZeUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_mIAgTbtp, 0, m, &hTable_mIAgTbtp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_oR9Gieiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 3000.0f, 0, m, &cBinop_uvLFGQ3o_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1CdEppHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_mIAgTbtp, 0, m, &hTable_mIAgTbtp_sendMessage);
}

void Heavy_ChaffVerb::cCast_Xl2jtKNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VkkHeLhM, 0, m, &cDelay_VkkHeLhM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nRck9ON5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_EevCCH2a, 2, m, &cDelay_EevCCH2a_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VAgOopnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LJaFtyr9, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_AW2BhyNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jkXtgQKc, HV_BINOP_SUBTRACT, 0, m, &cBinop_jkXtgQKc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vcD6nTP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1sFMeHbM_sendMessage);
}

void Heavy_ChaffVerb::cSystem_1sFMeHbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_h5KUEZwU_sendMessage);
}

void Heavy_ChaffVerb::cVar_Gc8KXJNQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N8H19BUo_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_Cfx6xCKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Cfx6xCKw, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2E1gdxeO, 0, m, &cDelay_2E1gdxeO_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Z2Rs1L7l, 0, m, &sTabread_Z2Rs1L7l_sendMessage);
}

void Heavy_ChaffVerb::cDelay_2E1gdxeO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2E1gdxeO, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Z2Rs1L7l, 0, m, &sTabread_Z2Rs1L7l_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2E1gdxeO, 0, m, &cDelay_2E1gdxeO_sendMessage);
}

void Heavy_ChaffVerb::sTabread_Z2Rs1L7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_kKwhalB9, HV_BINOP_SUBTRACT, 0, m, &cBinop_kKwhalB9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_VXcbu3Ru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gdYpZGuD, HV_BINOP_MAX, 0, m, &cBinop_gdYpZGuD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_h5KUEZwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VXcbu3Ru, HV_BINOP_MULTIPLY, 0, m, &cBinop_VXcbu3Ru_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jkXtgQKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yw4S8gH5_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Z2Rs1L7l, 0, m, &sTabread_Z2Rs1L7l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vqgDQLuU_sendMessage);
}

void Heavy_ChaffVerb::cSystem_RGHTkuBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kKwhalB9, HV_BINOP_SUBTRACT, 1, m, &cBinop_kKwhalB9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2E1gdxeO, 2, m, &cDelay_2E1gdxeO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_N8H19BUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RGHTkuBB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yw4S8gH5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cfx6xCKw, 0, m, &cDelay_Cfx6xCKw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2E1gdxeO, 0, m, &cDelay_2E1gdxeO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QtDIs4du_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_gdYpZGuD, HV_BINOP_MAX, 1, m, &cBinop_gdYpZGuD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gdYpZGuD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jkXtgQKc, HV_BINOP_SUBTRACT, 1, m, &cBinop_jkXtgQKc_sendMessage);
}

void Heavy_ChaffVerb::cCast_vqgDQLuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cfx6xCKw, 0, m, &cDelay_Cfx6xCKw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4bURRFJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cfx6xCKw, 2, m, &cDelay_Cfx6xCKw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kKwhalB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4bURRFJP_sendMessage);
}

void Heavy_ChaffVerb::cCast_64Cj6UsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Gc8KXJNQ, 0, m, &cVar_Gc8KXJNQ_sendMessage);
  cMsg_vcD6nTP6_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_AW2BhyNt, 0, m, &cTabhead_AW2BhyNt_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_bVQ1z4YJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ALjM3CGh_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_ALjM3CGh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xFkNRah9_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_rUdcJEEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Oy9gjPeE, HV_BINOP_ADD, 0, m, &cBinop_Oy9gjPeE_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_p12P9eSg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bSGpL9N5_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_bSGpL9N5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ir1OwoHK_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_Aczh8Mxg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_59dxVqd1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0ypnCVZR_sendMessage);
}

void Heavy_ChaffVerb::cVar_PUENAyhw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MvNbwmLS, 0, m, &cVar_MvNbwmLS_sendMessage);
}

void Heavy_ChaffVerb::cVar_MvNbwmLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VcSU2W1F, HV_BINOP_ADD, 0, m, &cBinop_VcSU2W1F_sendMessage);
}

void Heavy_ChaffVerb::cVar_NB9wU9AZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4qzR92CY, HV_BINOP_ADD, 0, m, &cBinop_4qzR92CY_sendMessage);
}

void Heavy_ChaffVerb::cVar_y55JL9rC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0YOE2q0s_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Zbj0HRP7, 0, m, &cIf_Zbj0HRP7_sendMessage);
}

void Heavy_ChaffVerb::cUnop_8b9NAgzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4qzR92CY, HV_BINOP_ADD, 1, m, &cBinop_4qzR92CY_sendMessage);
}

void Heavy_ChaffVerb::cUnop_BZxY6Qbt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4qzR92CY, HV_BINOP_ADD, 1, m, &cBinop_4qzR92CY_sendMessage);
}

void Heavy_ChaffVerb::cIf_Zbj0HRP7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_BZxY6Qbt_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_8b9NAgzv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_0YOE2q0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zbj0HRP7, 1, m, &cIf_Zbj0HRP7_sendMessage);
}

void Heavy_ChaffVerb::cVar_UMf3Fzz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ihjzmfs7_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_LqqQlWl9, 0, m, &cIf_LqqQlWl9_sendMessage);
}

void Heavy_ChaffVerb::cUnop_jeE33xAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_92mM6yLc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_j4PvWtNo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_92mM6yLc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cIf_LqqQlWl9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_j4PvWtNo_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_jeE33xAO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_ihjzmfs7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LqqQlWl9, 1, m, &cIf_LqqQlWl9_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_92mM6yLc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KZOiJutY, 0, m, &cSlice_KZOiJutY_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5ULcDOyj, 0, m, &cSlice_5ULcDOyj_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b3jJh35X_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SEL2717p_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cSlice_KZOiJutY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_I3HTsRbZ, 0, m, &cVar_I3HTsRbZ_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_I3HTsRbZ, 0, m, &cVar_I3HTsRbZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSlice_5ULcDOyj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_N2xN9SWn, HV_BINOP_NEQ, 1, m, &cBinop_N2xN9SWn_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_I3HTsRbZ, 1, m, &cVar_I3HTsRbZ_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_N2xN9SWn, HV_BINOP_NEQ, 1, m, &cBinop_N2xN9SWn_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_I3HTsRbZ, 1, m, &cVar_I3HTsRbZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cVar_I3HTsRbZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CAPkOIRD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aQmJHtAL_sendMessage);
}

void Heavy_ChaffVerb::cIf_0v7mHeNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Xn0F7hkN_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wylY4QoV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_wylY4QoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_I3HTsRbZ, 0, m, &cVar_I3HTsRbZ_sendMessage);
}

void Heavy_ChaffVerb::cCast_Xn0F7hkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N2xN9SWn, HV_BINOP_NEQ, 1, m, &cBinop_N2xN9SWn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_N2xN9SWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0v7mHeNz, 1, m, &cIf_0v7mHeNz_sendMessage);
}

void Heavy_ChaffVerb::cCast_b3jJh35X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N2xN9SWn, HV_BINOP_NEQ, 0, m, &cBinop_N2xN9SWn_sendMessage);
}

void Heavy_ChaffVerb::cCast_SEL2717p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0v7mHeNz, 0, m, &cIf_0v7mHeNz_sendMessage);
}

void Heavy_ChaffVerb::cIf_pgEnseIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_PUENAyhw, 0, m, &cVar_PUENAyhw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_uHXb7ajr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_pgEnseIu, 0, m, &cIf_pgEnseIu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_tnSToyym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_pgEnseIu, 0, m, &cIf_pgEnseIu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_MCiLUuLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_pgEnseIu, 0, m, &cIf_pgEnseIu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_kZycz411_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_Aczh8Mxg, 0, m, &cVar_Aczh8Mxg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_q3rDK5Ai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NB9wU9AZ, 0, m, &cVar_NB9wU9AZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lq3iT8P4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_uHXb7ajr, 1, m, &cIf_uHXb7ajr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BUX5Ftml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_MCiLUuLp, 1, m, &cIf_MCiLUuLp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QcTynaPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_uHXb7ajr, 1, m, &cIf_uHXb7ajr_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_tnSToyym, 1, m, &cIf_tnSToyym_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_MCiLUuLp, 1, m, &cIf_MCiLUuLp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_FWtEicuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rUdcJEEk, 0, m, &cVar_rUdcJEEk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7ToFA9Mp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_FWtEicuA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Ir1OwoHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_Aczh8Mxg, 0, m, &cVar_Aczh8Mxg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5m8wKrhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wnWsOMms, HV_BINOP_MULTIPLY, 0, m, &cBinop_wnWsOMms_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OkqMvj7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5m8wKrhQ, HV_BINOP_MOD_UNIPOLAR, 0, m, &cBinop_5m8wKrhQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tpPFnysf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_tnSToyym, 1, m, &cIf_tnSToyym_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4qzR92CY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KI0pKpaJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MdANpgLh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_odsxXNxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OPQeRErB, 0, m, &cVar_OPQeRErB_sendMessage);
}

void Heavy_ChaffVerb::cCast_MdANpgLh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PUENAyhw, 0, m, &cVar_PUENAyhw_sendMessage);
}

void Heavy_ChaffVerb::cCast_KI0pKpaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_odsxXNxf, HV_BINOP_ADD, 1, m, &cBinop_odsxXNxf_sendMessage);
}

void Heavy_ChaffVerb::cCast_aQmJHtAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4Oj7Hbe5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_CAPkOIRD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QcTynaPA_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_52oE43aW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_31QHT4BV, 0, m, &cVar_31QHT4BV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wnWsOMms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tnSToyym, 0, m, &cIf_tnSToyym_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dJQGhVrX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MCiLUuLp, 0, m, &cIf_MCiLUuLp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TCLuiTMf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_zhXivI55_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 3.1415f, 0, m, &cBinop_dJQGhVrX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_EZNsXLOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 314.0f, 0, m, &cBinop_2Cg2NSuh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2Cg2NSuh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_TCLuiTMf_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XKT11r1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SAYtVUv1, 1, m, &cVar_SAYtVUv1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NKNY9KJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lgWaErcI, 0, m, &cVar_lgWaErcI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yuePTcK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f7BAu6ZJ, 0, m, &cVar_f7BAu6ZJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xFkNRah9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_PUENAyhw, 0, m, &cVar_PUENAyhw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Oy9gjPeE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kRf6c3VH, HV_BINOP_MULTIPLY, 0, m, &cBinop_kRf6c3VH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kRf6c3VH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kZycz411, 0, m, &cIf_kZycz411_sendMessage);
}

void Heavy_ChaffVerb::cBinop_saqSZLmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_odsxXNxf, HV_BINOP_ADD, 0, m, &cBinop_odsxXNxf_sendMessage);
}

void Heavy_ChaffVerb::cCast_59dxVqd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_saqSZLmF, HV_BINOP_ADD, 1, m, &cBinop_saqSZLmF_sendMessage);
}

void Heavy_ChaffVerb::cCast_0ypnCVZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PUENAyhw, 0, m, &cVar_PUENAyhw_sendMessage);
}

void Heavy_ChaffVerb::cCast_9SR9QxRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_bVQ1z4YJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_x4U7K5Sx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pgEnseIu, 1, m, &cIf_pgEnseIu_sendMessage);
}

void Heavy_ChaffVerb::cCast_a43txA9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kRf6c3VH, HV_BINOP_MULTIPLY, 1, m, &cBinop_kRf6c3VH_sendMessage);
}

void Heavy_ChaffVerb::cCast_2pTqvvMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rUdcJEEk, 0, m, &cVar_rUdcJEEk_sendMessage);
}

void Heavy_ChaffVerb::cCast_3sSgtaMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_p12P9eSg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_cXYb0wpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kZycz411, 1, m, &cIf_kZycz411_sendMessage);
}

void Heavy_ChaffVerb::cCast_K92XLsKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rUdcJEEk, 0, m, &cVar_rUdcJEEk_sendMessage);
}

void Heavy_ChaffVerb::cCast_nDxYRgeS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Oy9gjPeE, HV_BINOP_ADD, 1, m, &cBinop_Oy9gjPeE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_q7WcSV8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_saqSZLmF, HV_BINOP_ADD, 0, m, &cBinop_saqSZLmF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VcSU2W1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q7WcSV8S, HV_BINOP_MULTIPLY, 0, m, &cBinop_q7WcSV8S_sendMessage);
}

void Heavy_ChaffVerb::cCast_AAah0Uzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q7WcSV8S, HV_BINOP_MULTIPLY, 1, m, &cBinop_q7WcSV8S_sendMessage);
}

void Heavy_ChaffVerb::cCast_if78PcrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PUENAyhw, 0, m, &cVar_PUENAyhw_sendMessage);
}

void Heavy_ChaffVerb::cCast_HqIQIZ2H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PUENAyhw, 0, m, &cVar_PUENAyhw_sendMessage);
}

void Heavy_ChaffVerb::cCast_Zc3KaB9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VcSU2W1F, HV_BINOP_ADD, 1, m, &cBinop_VcSU2W1F_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0aXaCiad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CAPkOIRD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aQmJHtAL_sendMessage);
}

void Heavy_ChaffVerb::cReceive_E2RHRskd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5ilJ1Xjx_sendMessage(_c, 0, m);
  cMsg_LM0t4SnY_sendMessage(_c, 0, m);
  cMsg_b1F0mr6o_sendMessage(_c, 0, m);
  cMsg_SMLWZ9R2_sendMessage(_c, 0, m);
  cMsg_yvhj2Hc2_sendMessage(_c, 0, m);
  cMsg_c1cjDpJV_sendMessage(_c, 0, m);
  cMsg_c04O9FAS_sendMessage(_c, 0, m);
  cMsg_JAcQcf3Q_sendMessage(_c, 0, m);
  cMsg_l68FpaAh_sendMessage(_c, 0, m);
  cMsg_YryOYtpC_sendMessage(_c, 0, m);
  cMsg_voTGrck6_sendMessage(_c, 0, m);
  cMsg_nfOpOV86_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Z3WHAwJW, 0, m, &cVar_Z3WHAwJW_sendMessage);
  cMsg_9bYeIqsc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_0vY0zf7a, 0, m, &cVar_0vY0zf7a_sendMessage);
  cMsg_GfY6y3OS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lMcABg8R, 0, m, &cVar_lMcABg8R_sendMessage);
  cMsg_vGRfmo66_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Xn3p4Wkh, 0, m, &cVar_Xn3p4Wkh_sendMessage);
  cMsg_GXQSexDf_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_uvHpYS5q, 0, m, &cVar_uvHpYS5q_sendMessage);
  cMsg_2N9bKptX_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lgWaErcI, 0, m, &cVar_lgWaErcI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OkpriRfd, 0, m, &cVar_OkpriRfd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_31QHT4BV, 0, m, &cVar_31QHT4BV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XsoDXfYE, 0, m, &cVar_XsoDXfYE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_C8qvgVEY, 0, m, &cVar_C8qvgVEY_sendMessage);
  cMsg_ubLYbhVr_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_f7BAu6ZJ, 0, m, &cVar_f7BAu6ZJ_sendMessage);
  cMsg_LG0SZseJ_sendMessage(_c, 0, m);
  cSwitchcase_sxE1rM2m_onMessage(_c, NULL, 0, m, NULL);
  cMsg_xFkNRah9_sendMessage(_c, 0, m);
  cMsg_0aXaCiad_sendMessage(_c, 0, m);
  cMsg_Ir1OwoHK_sendMessage(_c, 0, m);
  cSwitchcase_GK6v2SzP_onMessage(_c, NULL, 0, m, NULL);
  cVar_onMessage(_c, &Context(_c)->cVar_JuBjlJal, 0, m, &cVar_JuBjlJal_sendMessage);
  cMsg_Xqn0GULS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_b3JViUzi, 0, m, &cVar_b3JViUzi_sendMessage);
  cMsg_7w1Yx4dk_sendMessage(_c, 0, m);
  cMsg_8F8fddys_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_M4Mu8DTZ, 0, m, &cVar_M4Mu8DTZ_sendMessage);
  cMsg_9BEkpWKN_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_kbp9ZY19, 0, m, &cTabhead_kbp9ZY19_sendMessage);
  cMsg_2aUzXwwI_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3BuTpOJv, 0, m, &cVar_3BuTpOJv_sendMessage);
  cMsg_hgNI4mgB_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_449Ew2Ts, 0, m, &cTabhead_449Ew2Ts_sendMessage);
  cMsg_xErKRWcc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_z56r03Rq, 0, m, &cVar_z56r03Rq_sendMessage);
  cMsg_bdJ36u3R_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_PiwKv6yL, 0, m, &cTabhead_PiwKv6yL_sendMessage);
  cMsg_Bl8AX1jO_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_nFVe3oHL, 0, m, &cVar_nFVe3oHL_sendMessage);
  cMsg_LZmz9gd9_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_8ABEGJvL, 0, m, &cTabhead_8ABEGJvL_sendMessage);
  cMsg_NPlKGRQN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_B1Hsykvz, 0, m, &cVar_B1Hsykvz_sendMessage);
  cMsg_IBf6TNbc_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_YuSMcQsu, 0, m, &cTabhead_YuSMcQsu_sendMessage);
  cMsg_GhODPYu5_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ILBjhUwg, 0, m, &cVar_ILBjhUwg_sendMessage);
  cMsg_81oqzR5O_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_op7odMY5, 0, m, &cTabhead_op7odMY5_sendMessage);
  cMsg_gB2gco1e_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_A7pJbzQa, 0, m, &cVar_A7pJbzQa_sendMessage);
  cMsg_VaCjELye_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_yXkPKi2m, 0, m, &cTabhead_yXkPKi2m_sendMessage);
  cMsg_bOiEcMS7_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_AaIFL8LU, 0, m, &cVar_AaIFL8LU_sendMessage);
  cMsg_6Niutkem_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_hXO3fcjJ, 0, m, &cTabhead_hXO3fcjJ_sendMessage);
  cMsg_ISUHIkm3_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_GneM7Q8c, 0, m, &cVar_GneM7Q8c_sendMessage);
  cMsg_ER4DJTYK_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_K7RyFZAL, 0, m, &cTabhead_K7RyFZAL_sendMessage);
  cMsg_G37moVJT_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_LLwKJ2DY, 0, m, &cVar_LLwKJ2DY_sendMessage);
  cMsg_qvGX6TW2_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_1W4hWoEC, 0, m, &cTabhead_1W4hWoEC_sendMessage);
  cMsg_QtDIs4du_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Gc8KXJNQ, 0, m, &cVar_Gc8KXJNQ_sendMessage);
  cMsg_vcD6nTP6_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_AW2BhyNt, 0, m, &cTabhead_AW2BhyNt_sendMessage);
}

void Heavy_ChaffVerb::cReceive_POY7rgSw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_NKNY9KJ6_sendMessage);
}

void Heavy_ChaffVerb::cReceive_Wn4pB0Ij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UMf3Fzz0, 0, m, &cVar_UMf3Fzz0_sendMessage);
}

void Heavy_ChaffVerb::cReceive_pT7y5Ca9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pF57YmUH, 0, m, &cVar_pF57YmUH_sendMessage);
}

void Heavy_ChaffVerb::cReceive_Qc3Z9Elh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wnWsOMms, HV_BINOP_MULTIPLY, 1, m, &cBinop_wnWsOMms_sendMessage);
}

void Heavy_ChaffVerb::cReceive_p7Uc0oSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Zc3KaB9O_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HqIQIZ2H_sendMessage);
}

void Heavy_ChaffVerb::cReceive_LZy5LsT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AAah0Uzs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_if78PcrY_sendMessage);
}

void Heavy_ChaffVerb::cReceive_GRvxiMYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NB9wU9AZ, 0, m, &cVar_NB9wU9AZ_sendMessage);
}

void Heavy_ChaffVerb::cReceive_Fznjw77K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q3rDK5Ai_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_y55JL9rC, 0, m, &cVar_y55JL9rC_sendMessage);
}

void Heavy_ChaffVerb::cReceive_fGelSoQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_yuePTcK4_sendMessage);
}

void Heavy_ChaffVerb::cReceive_Qii7GLtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nDxYRgeS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K92XLsKM_sendMessage);
}

void Heavy_ChaffVerb::cReceive_P1ZphNSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a43txA9g_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2pTqvvMZ_sendMessage);
}

void Heavy_ChaffVerb::cReceive_ddR4PL4V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cXYb0wpV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3sSgtaMP_sendMessage);
}

void Heavy_ChaffVerb::cReceive_9Q9WIloS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_xJtE774L, m);
}

void Heavy_ChaffVerb::cReceive_OiEPzm9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_bFUcLZ3z, m);
}

void Heavy_ChaffVerb::cReceive_qpVwdLES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OkpriRfd, 0, m, &cVar_OkpriRfd_sendMessage);
}

void Heavy_ChaffVerb::cReceive_RslN4wDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_52oE43aW_sendMessage);
}

void Heavy_ChaffVerb::cReceive_o6othANf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FAV62Nt6, 0, m, &cVar_FAV62Nt6_sendMessage);
}

void Heavy_ChaffVerb::cReceive_59frYoOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oPSXzheC, 0, m, &cVar_oPSXzheC_sendMessage);
}

void Heavy_ChaffVerb::cReceive_5vIIEspB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uvHpYS5q, 0, m, &cVar_uvHpYS5q_sendMessage);
}

void Heavy_ChaffVerb::cReceive_rl9L58y3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_v0vQWkq4, m);
}

void Heavy_ChaffVerb::cReceive_DCDg1hWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_prxQkkA7, m);
}

void Heavy_ChaffVerb::cReceive_BIqY4UwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VXcbu3Ru, HV_BINOP_MULTIPLY, 1, m, &cBinop_VXcbu3Ru_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_64Cj6UsP_sendMessage);
}

void Heavy_ChaffVerb::cReceive_78PT4LC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x4U7K5Sx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9SR9QxRz_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_ChaffVerb::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_phasor_k_f(&sPhasor_Ax5YbSyP, VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf4), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf5), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf1), VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_0Y24QhQj, VOf(Bf4));
    __hv_line_f(&sLine_7ps0Bip1, VOf(Bf1));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf2));
    __hv_tabhead_f(&sTabhead_TJQykQGL, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_Ikhkn92g, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_O01VgdzB, VOf(Bf2));
    __hv_min_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf6));
    __hv_varread_f(&sVarf_8y7lEkG8, VOf(Bf2));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf2), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_nFb8TAAo, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_6CYHAJbK, VIi(Bi0), VOf(Bf2));
    __hv_sub_f(VIf(Bf7), VIf(Bf2), VOf(Bf7));
    __hv_sub_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf0));
    __hv_sub_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_floor_f(VIf(Bf7), VOf(Bf6));
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_abs_f(VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf6), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf7), VIf(Bf7), VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf8), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf9), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_tabhead_f(&sTabhead_zzHC3LEB, VOf(Bf4));
    __hv_var_k_f_r(VOf(Bf0), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_riZcPc92, VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_LiUUr7W1, VOf(Bf1));
    __hv_min_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_max_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf0));
    __hv_varread_f(&sVarf_47rxuoI7, VOf(Bf1));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_kmq1R0Op, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_3wYqntri, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf8), VIf(Bf1), VOf(Bf8));
    __hv_sub_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf8), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_KMUQLhrV, VIf(I0));
    __hv_varread_f(&sVarf_8W9GCEti, VOf(Bf2));
    __hv_rpole_f(&sRPole_zSznCkul, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_t6GtLLlE, VIf(Bf2), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_4Jr7TZZR, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_v0vQWkq4, VOf(Bf1));
    __hv_tabread_f(&sTabread_Z2Rs1L7l, VOf(Bf5));
    __hv_varread_f(&sVarf_prxQkkA7, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_tabwrite_f(&sTabwrite_LJaFtyr9, VIf(Bf9));
    __hv_varread_f(&sVarf_bFUcLZ3z, VOf(Bf9));
    __hv_fma_f(VIf(I0), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabread_f(&sTabread_voxtaPEX, VOf(Bf9));
    __hv_varread_f(&sVarf_fT3u6SEp, VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_qpEtdoNK, VOf(Bf2));
    __hv_rpole_f(&sRPole_FiKuGxU7, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf2), VIf(Bf9), VOf(Bf2));
    __hv_line_f(&sLine_GQDNNPqU, VOf(Bf1));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_KzGWmAVR, VOf(Bf2));
    __hv_tabread_f(&sTabread_yTfcWTOF, VOf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(Bf0), VOf(Bf8));
    __hv_tabread_f(&sTabread_gc69BEPk, VOf(Bf4));
    __hv_add_f(VIf(Bf8), VIf(Bf4), VOf(Bf6));
    __hv_tabread_f(&sTabread_jd8v8eTI, VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf3));
    __hv_tabread_f(&sTabread_afV6PBIq, VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf10), VOf(Bf11));
    __hv_tabread_f(&sTabread_D5pz8pIq, VOf(Bf12));
    __hv_add_f(VIf(Bf11), VIf(Bf12), VOf(Bf13));
    __hv_tabread_f(&sTabread_l34qTGku, VOf(Bf14));
    __hv_tabwrite_f(&sTabwrite_xvcTTCIt, VIf(Bf5));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_8WxOzIRJ, VIf(Bf0));
    __hv_sub_f(VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_f1b2SbLs, VIf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_KVZuN0wL, VIf(Bf7));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_eK1EKK8w, VIf(Bf12));
    __hv_sub_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_jvWti33b, VIf(Bf10));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_tabread_f(&sTabread_ctLULMbY, VOf(Bf9));
    __hv_varread_f(&sVarf_KQ7zHV9X, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_Cy93JAJg, VOf(Bf3));
    __hv_rpole_f(&sRPole_gq8w1ZlP, VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf3));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf13), VIf(Bf14), VOf(Bf9));
    __hv_tabread_f(&sTabread_Bwo6FKNV, VOf(Bf3));
    __hv_varread_f(&sVarf_XOrJk30h, VOf(Bf10));
    __hv_mul_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_tiUtzi2h, VOf(Bf12));
    __hv_rpole_f(&sRPole_mVmkmH1I, VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf12));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf3));
    __hv_tabread_f(&sTabread_we43Zb4Y, VOf(Bf12));
    __hv_varread_f(&sVarf_9SvE3brO, VOf(Bf10));
    __hv_mul_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_SlMUDRHI, VOf(Bf11));
    __hv_rpole_f(&sRPole_XML0uIro, VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf3), VIf(Bf2), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_eF3lDk9I, VIf(Bf1));
    __hv_sub_f(VIf(Bf13), VIf(Bf14), VOf(Bf1));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf11));
    __hv_add_f(VIf(Bf1), VIf(Bf11), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_H2DgVUXc, VIf(Bf10));
    __hv_sub_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_c0Yu9ky1, VIf(Bf12));
    __hv_sub_f(VIf(Bf1), VIf(Bf11), VOf(Bf11));
    __hv_tabwrite_f(&sTabwrite_GzhOi7Ay, VIf(Bf11));
    __hv_line_f(&sLine_sKtHIecZ, VOf(Bf11));
    __hv_mul_f(VIf(Bf13), VIf(Bf11), VOf(Bf13));
    __hv_mul_f(VIf(Bf14), VIf(Bf11), VOf(Bf14));
    __hv_mul_f(VIf(Bf3), VIf(Bf11), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf14), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_xJtE774L, VOf(Bf3));
    __hv_mul_f(VIf(I0), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf11), VIf(Bf3), VOf(Bf11));
    __hv_add_f(VIf(Bf11), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf13), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_ChaffVerb::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s)
  float **const bIn = &inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_ChaffVerb::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s), uninterleave
  float *const bIn = inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
